package Lingua::EN::Opinion::Emotion;
$Lingua::EN::Opinion::Emotion::VERSION = '0.0503';
our $AUTHORITY = 'cpan:GENE';

use Moo;
use strictures 2;
use namespace::clean;


has wordlist => (
    is      => 'ro',
    builder => 1,
);

sub _build_wordlist {
    my %wordlist = (
        aback => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abacus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        abandon => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        abandoned => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        abandonment => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        abate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abatement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abba => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        abbot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        abbreviate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abbreviation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abdomen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abdominal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abduction => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        aberrant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aberration => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abeyance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abhor => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abhorrent => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        abject => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ablation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ablaze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abnormal => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abolish => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abolition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abominable => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abomination => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aboriginal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abortion => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        abortive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        abound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abovementioned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        abrasion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abroad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abrogate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abrupt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        abruptly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abscess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        absence => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        absent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        absentee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        absenteeism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        absinthe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        absolute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        absolution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        absorbed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        absorbent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        absorbing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        absorption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abstain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abstention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abstinence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abstract => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abstraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        absurd => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        absurdity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abundance => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        abundant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        abuse => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        abutment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        abysmal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        abyss => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        academic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        academy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accede => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accelerate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acceleration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accentuate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accept => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acceptable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acceptance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        access => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accessible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accessory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accident => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        accidental => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        accidentally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        accolade => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        accommodate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accommodation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accompaniment => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        accompany => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accompanying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accomplice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accomplish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accomplished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accomplishment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accord => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        accordance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accordion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        account => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        accountability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        accountable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        accountant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        accounting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accounts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        accredited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        accretion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accrue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accueil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        accumulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accumulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accuracy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accurate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        accursed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        accusation => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accusative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accused => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accuser => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accusing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        accustomed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ache => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        achieve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        achievement => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        aching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        acid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acknowledge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acknowledged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acknowledgment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acoustic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acoustics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acquaint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acquaintance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acquainted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acquiescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acquire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acquiring => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acquisition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acquisitions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acreage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acres => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acrobat => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        act => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        action => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        actionable => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        active => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        activity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        actor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        actual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        actuality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        actuary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acuity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acumen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        acupuncture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        acutely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adamant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adapt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adaptable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        add => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        added => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        addendum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adder => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        addiction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        addition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        additional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        additive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        address => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        addressee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        addresses => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adept => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adequacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adequate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adhere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adherence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adherent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adhering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        adhesion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adhesive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adieu => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adipose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjacency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjacent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjoining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjourn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjournment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjudicate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjudication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjunct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adjust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjustment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adjuvant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        administer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        administration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        administrative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        admirable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        admiral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        admiralty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admiration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        admire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        admirer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        admissibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admissible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        admission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admittance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admitted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admitting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admixture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        admonition => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ado => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adobe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adolescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adolescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adopt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adoption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adorable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adoration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        adore => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        adorn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adornment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adrift => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        adult => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adulterated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adultery => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        advance => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        advanced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        advancement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        advancing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        advantage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        advantageous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        advent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        adventure => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adventurer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adventurous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        adversary => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adverse => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        adversity => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        advertise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        advertisement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        advice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        advisable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        advise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        advised => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        advisement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        adviser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        advocacy => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        advocate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        aegis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aeration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aerial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aerodrome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aerodynamics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aeronautics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aeroplane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aesthetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aesthetics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aetiology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        afar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        affair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        affections => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affiche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affidavit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affiliated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        affiliation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affinity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affirm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        affirmation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        affirmative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        affirmatively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        affix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        afflict => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        afflicted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        affliction => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        affluence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        affluent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        afford => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        affront => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        afield => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        afore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aforementioned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aforesaid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        afraid => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        afresh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aftermath => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        afternoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aftertaste => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        afterthought => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aga => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        agate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        age => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agglomeration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggravated => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggravating => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        aggravation => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggregate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggregation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggression => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggressive => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aggressor => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aghast => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        agile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        agility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        agitated => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agitation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agnostic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ago => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agonizing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agony => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        agree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        agreeable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        agreed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        agreeing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        agreement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        agricultural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agriculture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aground => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        agua => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ahead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aiding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ailing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ailment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aimless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        air => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airbag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airlift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airplane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airport => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airs => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        airship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aisle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ait => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ajar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        akin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        alabaster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        alarm => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        alarming => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        alb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        album => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alchemy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alcohol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alcoholism => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        alcove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alertness => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        alerts => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        alfalfa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        algebra => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        algebraic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        algorithm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alibi => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alien => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alienate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alienated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        alienation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        alight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aligned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alignment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alimentation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        alimony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aliquot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alive => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        alkali => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alkaloids => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        allegation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allege => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alleged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allegiance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        allegorical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allegory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allegro => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        alleviate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        alleviation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        alley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alliance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        allied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        alligator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allocate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allotment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allowable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        allowance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allowed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alloy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        allure => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        alluring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        allusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alluvial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        almanac => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        almighty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aloft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aloha => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        alongside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aloof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aloud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alphabet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alphabetical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        altar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alteration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        altercation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        altered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alternate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alternative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        altitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        altogether => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alumnus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        alveolar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amalgam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amalgamation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amateur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amaze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        amazement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amazingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        ambassador => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        amber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ambient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ambiguity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ambiguous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ambit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ambition => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ambitious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ambulance => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ambush => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        ameliorate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        amenable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amendment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amends => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amenity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amethyst => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amiable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amicable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amidst => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ammonia => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ammunition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amnesia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amnesty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amorphous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amortization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        amount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amour => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ampersand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amphetamines => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amphibian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amphibious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amphitheater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amplification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amplify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amplitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amputation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amulet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        amuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amused => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amusement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        amusing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ana => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anaconda => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anaesthesia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anaesthetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analgesic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analogous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analogue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analogy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analysis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analyst => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        analytic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analyze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        analyzer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anarchism => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anarchist => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anarchy => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anastomosis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anathema => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        anatomic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anatomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ancestor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ancestral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ancestry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anchor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        anchorage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        ancient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ancillary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        androgen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anemone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        angel => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        angelic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        anger => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        angina => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        angiography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        angle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        angling => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        angry => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anguish => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        angular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anhydrous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        animal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        animate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        animated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        animation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        animosity => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        animus => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ankle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annals => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annexation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annexe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annihilate => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annihilated => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        annihilation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        annotate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annotation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        announce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        announcement => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annoy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annoyance => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annoying => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annuity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annul => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        annulment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        annulus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anointing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anomalous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anomaly => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        anon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anonymous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        answer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        answerable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        answering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antagonism => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antagonist => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antagonistic => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ante => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antecedent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antelope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antenna => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anterior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anthem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anthology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anthrax => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        anthropology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antibiotic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antibiotics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        antichrist => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anticipation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anticipatory => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antidote => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        antifungal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        antimony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antipathy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antiquarian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antiquated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antique => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        antiquity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antiseptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        antisocial => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        antithesis => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antithetical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antiviral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        antler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anvil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        anxiety => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        anxious => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aorta => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apache => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apartment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apathetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        apathy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aperture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aphid => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apiece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aplomb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        apocalyptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apologetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        apologist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apologize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        apology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        apostasy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apostate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apostle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        apostolic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        apostrophe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appalling => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apparatus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apparel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apparently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apparition => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        appeal => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appearance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appellant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        append => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appendage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appendicitis => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        appendix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appetite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appetizer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        applause => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        apple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appliance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appliances => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        applicability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        applicable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        applicant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        application => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appoint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appointment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appointments => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apportion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apportionment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appraise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appreciable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appreciation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        apprehend => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apprehension => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apprehensive => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apprentice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        apprenticeship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approaching => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approbation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        appropriation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        approve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        approving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        approximate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approximately => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approximating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        approximation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        appurtenances => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        apt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aptitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aqua => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aquamarine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aquarium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aquatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aqueduct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aqueous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arbiter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        arbitrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arbitration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arbitrator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        arbor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arc => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arcade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archaeological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archaeologist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archaeology => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        archaic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archbishop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archetype => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        archipelago => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        architect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        architecture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        archive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arctic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ardent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ardor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        arduous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        area => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arena => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        areola => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        argent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        argue => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        argument => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        argumentation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        argumentative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arguments => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        aristocracy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aristocrat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aristocratic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        arithmetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        armada => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        armament => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        armaments => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        armature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        armed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        armor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        armored => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        armory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        arms => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        army => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aroma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        arousal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arouse => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        arraignment => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        arrange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arranged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrangement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        array => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        arrears => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrival => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrive => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrogance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrogant => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arsenal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arsenic => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        arson => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        art => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 0 },
        artery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        artful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        arthropod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        artichoke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        article => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        articles => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        articulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        articulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        artifice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        artillery => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        artisan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        artist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        artiste => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        artistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        artists => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ascend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ascendancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ascension => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ascent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ascertain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ascertained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ascetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ashamed => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ashes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        asleep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asp => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aspartame => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aspect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aspects => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asphalt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aspiration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        aspire => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aspiring => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assail => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        assailant => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        assassin => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        assassinate => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assassination => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        assault => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assemblage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assemble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assembled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assembly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        assent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        assert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asserting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        assertion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assessment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 1 },
        assessor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        assets => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        asshole => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assignee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        assignment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assimilate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assimilation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        assistance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        assistant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        associate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        association => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        assorted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assortment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assuage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        assumed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assuming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assumption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        assurance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        assure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        assured => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        assuredly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        asterisk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asteroids => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astigmatism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astonishingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        astonishment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        astral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astray => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astringent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astrologer => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        astrology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astronaut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        astronomer => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        astronomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        astute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        asunder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asylum => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asymmetric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asymmetry => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        asymptotic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atelier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atheism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atheist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atheistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atherosclerosis => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        athlete => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        athletic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        athleticism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        athletics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atlas => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atmosphere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atmospheric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atoll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        atomic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atone => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        atonement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        atrium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atrocious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        atrocity => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        atrophy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        attach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attachment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        attack => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attacking => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        attain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attainable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        attainment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        attempt => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attendance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attendant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        attention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        attentive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        attenuate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attenuated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attenuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        attest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        attestation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        attic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attorney => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        attraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        attractiveness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        attributable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attribute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attribution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        attrition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auburn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auction => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auctioneer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        audacious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        audacity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        audible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        audience => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        audit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        audition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auditor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        auditorium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auditory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aught => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        augment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        augmentation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        august => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        aura => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aurora => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auspices => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auspicious => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        austere => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        austerity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        authentic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        authenticate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        authentication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        authenticity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        author => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        authoritative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        authority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        authorization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        authorize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        authorized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        authorship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        autobiography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        autocratic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        autograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        automatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        automobile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        autonomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        autopsy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        autumn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        auxiliary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avalanche => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        avarice => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avatar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        avenger => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avenue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        average => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        averse => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aversion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aviary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aviation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        aviator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avocado => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avoid => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avoidance => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        avoiding => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        await => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        awake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        awaken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        award => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        awe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        awful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        awkwardness => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        awning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        awry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        axial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        axiom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        axiomatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        axis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        axle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        aye => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        azimuth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        azure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        babble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        babbling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baboon => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        babysitter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        baccalaureate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        baccarat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bachelor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        back => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backbone => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        backer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        backfire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backgammon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        background => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backhoe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backpacker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backtrack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backwards => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        backwater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bacteria => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bacterium => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bad => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        badge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        badger => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        badly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        badness => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baffle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baggage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baggy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bagpipes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bailiff => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bait => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bakery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        balance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        balanced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        balcony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bald => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bale => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        balk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ball => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ballad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ballast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ballet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        balloon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ballot => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ballroom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        balm => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        balmy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        balsam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        balsamic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ban => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        banana => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        band => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bandage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bandit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bandwagon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bane => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bang => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        banger => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        banish => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        banished => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        banishment => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        banjo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        banker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bankrupt => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bankruptcy => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        banner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        banquet => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        banshee => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        banter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baptism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        baptismal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barb => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barbarian => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barbaric => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barbarism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barbecue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barbed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bareback => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barefoot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barf => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bargain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        barge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baritone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bark => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barney => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baroque => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barrack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barrel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barren => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        barricade => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barrier => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barrister => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        barrow => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bartender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        barter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        base => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        baseball => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baseboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baseless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basilica => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bask => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basketball => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        basso => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bassoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bastard => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bastion => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        batch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        batching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bathe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bathroom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bathymetry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        baton => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        battalion => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        batter => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        battered => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        battery => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        battle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        battled => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        battlefield => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bawdy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bayonet => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bayou => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bazaar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beacon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beads => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beagle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beaker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beaming => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bear => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bearded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bearer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bearing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bearings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bearish => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beast => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beastly => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beating => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        beau => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beautification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        beautiful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beautify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beauty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beckon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bedding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bedrock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bedroom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bedtime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bee => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beef => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beehive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beeswax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beetle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        befall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        befitting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        befriend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        beg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        beggar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        begging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        begin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beginner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beginning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        begun => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        behavior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        behemoth => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        behest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        behold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beholden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beholder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        believed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        believer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        believing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        belittle => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belligerent => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bellow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bellows => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belongings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        belt => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bemused => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bench => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beneath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        benefactor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        beneficial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beneficiary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        benefit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        benevolence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        benign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        benzene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bequeath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bequest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bereaved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bereavement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bereft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bergamot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        berlin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        berserk => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        berth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        beseech => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beset => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bestial => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bestow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        betray => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        betrayal => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        betrothed => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        betterment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        betting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        betty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bevel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beverage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bevy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        beware => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bewildered => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        bewilderment => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        bias => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biased => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biblical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bibliography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bickering => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bicolor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bicycle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bidder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bidding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biennial => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bier => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bifurcation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        big => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bigot => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bigoted => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bilateral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bilayer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bile => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bilge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bilingual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        billet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        billiards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        billion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        billy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bimonthly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        binary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bindery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        binding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        binocular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        binoculars => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        binomial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biogenesis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biographer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biopsy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biosphere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bipartite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        birch => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bird => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        birth => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        birthday => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        birthplace => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        birthright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bisexual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bishop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bitch => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bitterly => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bitterness => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bitumen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        biweekly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bizarre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        black => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blackberry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blackboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blackjack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blackmail => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blackness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blacksmith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bladder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blame => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blameless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blanket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        blasphemous => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blasphemy => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blast => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        blatant => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blaze => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blazing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bleach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bleak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bleeding => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blemish => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bless => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        blessed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        blessing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        blessings => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        blight => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blighted => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blinded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blindfold => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        blindfolded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blindly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blindness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bliss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        blissful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        blister => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blitz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        blizzard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bloated => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blob => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        block => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blockade => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blond => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bloodhound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bloodless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bloodshed => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        bloodthirsty => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bloody => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bloom => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        blossom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        blot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blowing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blowout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blues => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bluff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bluish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blunder => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        blunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blurred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        blushing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        board => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boarder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boarding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        boasting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bobbin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bodice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bodily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        body => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bodyguard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bogus => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boil => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boiler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boilerplate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boiling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boisterous => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        boldness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bolster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bolt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bolus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bomb => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        bombard => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bombardment => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bombed => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bomber => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bonanza => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bond => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bondage => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bonds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bones => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bonfire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bonne => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bonnet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bonus => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        bony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boob => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        book => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bookcase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bookish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bookkeeper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bookkeeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booklet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        books => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bookseller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bookshop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bookstore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bookworm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        boomerang => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        booming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        boost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boots => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        booze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        border => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bordering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boreal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boredom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        borer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        borough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        borrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        borrower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bosom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boston => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        botanical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        botanist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        botany => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bother => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bothering => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bottle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bottom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bottomless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boulder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bounce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boundary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boundless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bounds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bountiful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bounty => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bouquet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bourgeois => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bourgeoisie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bourse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bout => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bovine => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bowed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bowels => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bowl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bowls => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        box => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boxer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boxing => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boycott => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boyhood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        boyish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bracelet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        braces => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brachial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bracket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brackets => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brackish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        braid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brains => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        brainstorm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bran => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        branch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        branching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brandy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bravado => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bravery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        brawl => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brazen => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breadth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        break => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        breakable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breakdown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breaker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breakers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breakfast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        breakneck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breakup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        breath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breech => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breeches => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breeder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breeding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breeze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breezy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brethren => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        breve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brevity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brewing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bribe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bribery => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bridal => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bride => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bridegroom => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bridesmaid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        bridge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bridle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        briefly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brigade => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brighten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        brightness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        brilliant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        brim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brimming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brimstone => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brisk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bristle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brittle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        broadcast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        broadside => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brocade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        brochure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        broil => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        broke => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        broken => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        broker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brokerage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bronco => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bronze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brooding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        broom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        broth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brothel => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brother => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        brotherhood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        brotherly => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        brow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bruise => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brunette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brunt => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brutal => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brutality => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        brute => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bubble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bubbling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buck => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        bucket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buckle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buckled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buddy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        budge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        budget => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        buffalo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buffer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buffet => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bug => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bugaboo => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        buggy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bugle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        build => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        builder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        building => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        buildings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulbous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulkhead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulldog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bulldozer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bullet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulletin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulletproof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bullock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bully => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bulwark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bum => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bummer => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bunch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bundle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bungalow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bunk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bunker => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buoy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        buoyancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burdensome => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bureau => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bureaucracy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bureaucrat => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burglar => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burglary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burial => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        buried => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        burke => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        burlap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burlesque => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        burly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burnished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burnout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burnt => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burr => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        burrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bursary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bury => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        bus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bushel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bushy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        business => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        bust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        busted => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bustle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bustling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        busy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        butane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        butcher => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        butler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        butt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        butter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        butterfly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buttery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        buttock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        button => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buttress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buxom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        buy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buyer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buzz => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        buzzed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        buzzer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bye => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bygone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        bylaw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        bystander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        byte => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cabal => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cabbage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cabin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cabinet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        cabriolet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cache => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cacophony => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cad => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cadaver => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        caddy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cadence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cadet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cafe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cairn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calamity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        calcareous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calculate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calculated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calculating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calculation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calculator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        calculus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calendar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        caliber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calibrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calico => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calipers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        call => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calligraphy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        callous => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calls => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        calm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        calmness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caloric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calorie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        calorimeter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        camber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        camel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cameo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cameraman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        camisole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        camouflage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        camouflaged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        camp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        campaign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        campaigner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        campaigning => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        campus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cancel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        canceling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cancellation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cancer => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        candid => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        candidacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        candidate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        candied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        candle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        candlelight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        candlestick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        candor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        candy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cane => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canister => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canker => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cannibal => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cannibalism => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cannon => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canoe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canonical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        canopy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canteen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canterbury => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cantilever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canton => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canvas => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        canvass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cap => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        capability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capacity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capillary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capital => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capitalist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        capitals => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capitol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capitulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caprice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capricious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capsule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        captain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        caption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        captivate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        captivating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        captive => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        captivity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        captor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        capture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        car => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caramel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caravan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carbon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carcass => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        carcinoma => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        card => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cardigan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cardinal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cardiomyopathy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        care => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        career => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        careful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        carefully => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        carelessness => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        caret => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caretaker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cargo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caribou => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caricature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caries => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carnage => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        carnal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carnation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carnivorous => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        carousel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carpenter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carriage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carried => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carrier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carrying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartilage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartographic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartouche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cartridge => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        carving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cascade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        case => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        casein => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cash => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cashier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        cashmere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        casing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        casino => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cask => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        casket => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caste => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        castle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        castor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        casual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        casually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        casualty => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catabolism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catalog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catalogue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catalysis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catalytic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catamaran => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catapult => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cataract => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        catastrophe => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        catch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        catching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catechism => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        categorical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        category => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        caterer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caterpillar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cates => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cathartic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cathedral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        catheter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catholic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        catnip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cattle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caucus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caudal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caulk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        causal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        causality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        causation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caused => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        causeway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caution => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cautionary => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cautious => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cautiously => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cavalry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        caveat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cavern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cavernous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cavity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cayenne => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ceaseless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cede => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ceiling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        celebrant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        celebrated => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        celebrating => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        celebration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        celebrity => { anger => 1, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        celestial => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        celibacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cellar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cellular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        celluloid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cement => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        cemented => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cemetery => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        censor => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        censure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        census => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centenary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centennial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        center => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        centimeter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        central => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centrality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centralization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centralize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centrally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centrifugal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centrifuge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        centurion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        century => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ceramics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cereal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cereals => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cerebral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ceremonial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ceremony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        certainty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        certificate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        certify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        cess => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cessation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chaff => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chafing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chagrin => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        chain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chairman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        chairperson => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chairwoman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        chaise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chalet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chalice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chalk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        challenge => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chamber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chambers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chameleon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        champagne => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        champion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        chance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        chancellor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        chandelier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chandler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        change => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        changeable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        changed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        changer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        changing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        channel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chant => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        chaos => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        chaotic => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chapel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chaplain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        chapman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chaps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chapter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        char => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        character => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        characteristic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        characterize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        charade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        charcoal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        charge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chargeable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        charger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chariot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        charitable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        charity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        charm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        charmed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        charmer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        charming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        charter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chartered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chasm => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chastisement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chastity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        chat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chateau => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chatter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chattering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chatty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chauffeur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheat => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        check => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        checker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        checkered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        checkers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        checklist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cheek => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheeks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheer => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        cheerful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        cheerfulness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cheering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cheery => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cheesecake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheetah => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chemise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chemist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        chemistry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cheque => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cherish => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        cherry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chestnut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chevron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chicane => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 1 },
        chicken => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chiefly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chieftain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        child => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        childbirth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        childhood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        childish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chilly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chimera => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        chimes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chimney => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        china => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chinook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chipping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chirp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chisel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chivalry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chloroform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chocolate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        choice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        choir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        choke => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cholera => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        choose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        choosing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chopping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chops => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        choral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chords => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chorus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chosen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        chowder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        christening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chromatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chromatography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chromosome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chronic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        chronicle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        chronograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chronological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chuck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chuckle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        chunk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chunky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        church => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        churchyard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        churn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        chutney => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ciao => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cider => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cigar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cigarette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cinch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cinder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cinema => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cinematographer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cinematography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cinnamon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cipher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circuit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circumcision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        circumference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circumferential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circumscribed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circumstance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circumstantial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        circumvention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        circus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cirrus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cistern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        citadel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        citation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        citizen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        citrine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        city => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        civic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        civil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        civilian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        civility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        civilization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        civilized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        clad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        claim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        claimant => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clairvoyant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        clam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clamor => { anger => 1, anticipation => 1, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        clamp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        clandestine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clap => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        clarify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        clarinet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clarion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clash => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clashing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clasp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        class => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        classic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        classical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        classics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        classification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        classify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        classmate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clatter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clause => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clauses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        claw => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        claws => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cleaning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cleanliness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cleanly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cleanse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cleansing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        clearance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        clearing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clearness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cleavage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cleave => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clef => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cleft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clemency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clergy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clergyman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clerical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        clerk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clerkship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cleverness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        click => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        client => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clientele => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cliff => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        climate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        climatology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        climax => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        climb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clipper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clipping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clique => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cloak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clock => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clockwork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cloister => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        close => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        closed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        closeness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        closet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        closure => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        clot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cloth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clothe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        clothes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clothesline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clothing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cloud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clouded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cloudiness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cloudy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        clover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cloves => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clown => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        club => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clubhouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clubs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clue => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clumsy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cluster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clutch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clutches => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        clutter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        coagulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coalesce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        coalition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        coast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        coastal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coaster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        cobalt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cobble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cobbler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cobra => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cocaine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cockpit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cocktail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cocoa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cocoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        code => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        codex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        codification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        codify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coefficient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coerce => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coercion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        coercive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coexist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        coexistence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coexisting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        coffee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coffin => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cogent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cognate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cognition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cognitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cohabitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coherence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        coherent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cohesion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        cohesive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cohort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coiled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coinage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coincide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coincidence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        coincident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coinciding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coldly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coldness => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        colic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collaborator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        collapse => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        collar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collateral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        collation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colleague => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collectively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        collector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        college => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collegiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collision => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colloquial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        collusion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        colon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colonel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        colonial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colophon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        color => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coloration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colored => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coloring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colorless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colors => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        colossal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        colt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        column => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        columnar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coma => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        comatose => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        comb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combat => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combatant => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combative => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combinatorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combustible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        combustion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comedy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comfort => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        comforter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coming => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        command => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commandant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        commander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commanding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        commemorate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        commemoration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commemorative => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commendable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        commensurate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commentator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commerce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        commercial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commissary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        commissioner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        committal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        committed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        committee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        commodity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commodore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        common => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commonly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commonplace => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        commons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commonwealth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        commotion => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        communicable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        communicate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        communication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        communicative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        communion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        communism => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        communist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        community => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commutation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commutative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        commute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        commuter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        compaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compactness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        companion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        companionship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        company => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comparable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comparative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comparatively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comparison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compartment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        compassion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compassionate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compatibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compatible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compelled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compelling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compendium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compensate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        compensation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compensatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        competence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        competency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        competent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        competition => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        competitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        competitor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compilation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complacency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        complacent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complain => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        complaint => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complement => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        complementary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        completed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        completely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        completeness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        completing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        completion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        complex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complexed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complexion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complexity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compliance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        compliant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        complicate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complicated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complicity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compliment => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        comply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        complying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        component => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        composed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        composer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        composite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        composition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compost => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        composure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comprehend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        comprehension => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comprehensive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        compress => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compressed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compressible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compression => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comprise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compromise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comptroller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        compulsion => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compulsory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        computable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        computation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        compute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        computer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        comrade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        con => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concatenation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conceal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        concealed => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        concealment => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conceit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conceited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conceivable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concentrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concentration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concentric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concerned => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        concert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concessional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concierge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conciliation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        concise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conclave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conclude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concluding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conclusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concoction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concomitant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concord => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        concordance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        concours => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concourse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concrete => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concurrence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concurrent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concurring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        concussion => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        condemn => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        condemnation => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        condensation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        condensed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        condescending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        condescension => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        condiment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        condition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conditional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conditionally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conditioned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conditions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        condolence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        condone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conducive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conduct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conductivity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conductor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conduit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confederate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        confederation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        confession => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        confessional => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        confessions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        confidence => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        confident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        confidential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        confidentially => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        configuration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confine => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        confined => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        confinement => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        confines => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confirm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confirmation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        confirmatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confirmed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        confiscate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        confiscation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conflagration => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conflict => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        conflicting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confluence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conformance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conformation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conformity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        confound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confounded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confront => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        confusion => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        congenial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        congenital => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        congestion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conglomerate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        conglomeration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        congratulatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        congregate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        congregation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        congress => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        congressional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        congressman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        congruence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        conic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjecture => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjugal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjugate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjugation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjunction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjunctive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conjure => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        conjuring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        connect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        connected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        connection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        connective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        connoisseur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        conquer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conqueror => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conquest => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conscience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        conscientious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        consciousness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conscription => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consecration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        consecutive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consenting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consequence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consequent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conservation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        conservatism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conservative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conservatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conserve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        considerable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        considerate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        consignee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consignment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consistency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        consistent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consolation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        console => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        consolidate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consolidation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consonant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        consort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        conspicuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conspiracy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conspirator => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conspire => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        constancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        constant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        constantly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        constellation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consternation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constipation => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constituent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constituents => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constitute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        constitution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constitutional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        constitutionality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constrain => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constrained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        constraint => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        construct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        construction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        construe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consul => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        consult => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        consultation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consuming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consummate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        consummation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        consumption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        contagion => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contagious => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        containment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contaminate => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contaminated => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        contamination => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contemplate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contemplation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        contemplative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contemporaneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contemporary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contempt => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contemptible => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contemptuous => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        content => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        contention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contentious => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contents => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        context => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contiguous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contingency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contingent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continuance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continuation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continue => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        continued => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continuing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continuity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        continuously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        contraband => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contract => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contracted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contractile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contracting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contradict => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contradiction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contradictory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contrary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contrast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contrasted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contravene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contravention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        contribute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        contributor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        contrived => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        control => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        controversial => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        controversy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conundrum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convalescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convenience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conveniences => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convenient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        convent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        convention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conventional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        converge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convergence => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convergent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conversant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        conversation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conversational => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        converse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conversing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conversion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        converted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convertible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convexity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conveyance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        conveyancing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        convict => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        conviction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convince => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        convinced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        convincing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        convocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convoluted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convolution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        convoy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cookery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cooking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cool => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cooler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cooling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coolness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        coop => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cooperate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cooperating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cooperation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cooperative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        coordinate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cop => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        copious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        copper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        copy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        copycat => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        copying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        copyright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cord => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cordon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corduroy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        core => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corkscrew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cornea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cornet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cornice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cornstarch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corollary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corona => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coronation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        coroner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corporal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corporate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corporation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        corporeal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        corps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corpse => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        corpus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        correction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corrective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        correctness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        correlation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        correlative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        correspond => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        correspondence => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        correspondent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corridor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corroborate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        corroboration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        corrosion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corrosive => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corrupt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corrupting => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        corruption => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        corset => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cortex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cortical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        corvette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cosmetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cosmetics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cosmic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cosmology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cosmopolitan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cosmos => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        costly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        costume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cosy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cottage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cotton => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        couch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cougar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cough => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        council => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        counsel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        counsellor => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        counselor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        count => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        countdown => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        countenance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        counter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        counteract => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        counterbalance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        counterclaim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        counterpart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        countess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        countless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        country => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        countryman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        counts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        county => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        coup => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        couple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coupled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coupon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        courage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        courageous => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        courier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        courses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coursing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        court => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        courteous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        courtesy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        courthouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        courts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        courtship => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        courtyard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cove => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        covenant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        covered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        covering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        covert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        covet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coward => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cowardice => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cowardly => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cowboy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cowhide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cowl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coworker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        coyote => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crabby => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cracked => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cracker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cracking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crackle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cradle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        craft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        craftsman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        crafty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        craig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crammed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cramp => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cramped => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cranium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cranky => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crap => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        craps => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crash => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        crate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crave => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        craving => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crawfish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crawl => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crayons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        craze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crazed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crazy => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        creaking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cream => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        creamer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creamy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        create => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        creation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        creator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creature => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        credence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        credential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        credentials => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        credibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        credible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        credit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        creditable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        credited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        crediting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creditor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creek => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        creeping => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cremation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        creole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crescendo => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        crescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crevice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        crib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cricket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crime => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        criminal => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        criminality => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crimp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crimson => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cringe => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cripple => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crippled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crisis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crisp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        criterion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        critic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        criticism => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        criticize => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        critique => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        critter => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        croak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crockery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crocodile => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        croft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        croquet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cross => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crossbow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crossed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crossing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crotch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crouch => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crouched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crouching => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        croupier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crowd => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crowded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crowning => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        crucial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cruciate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crucifix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crucifixion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crude => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cruel => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cruelly => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cruelty => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cruise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cruiser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crumb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crumbling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crunch => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crusade => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crushed => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crushing => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crusty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crutch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crux => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        crypt => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cryptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cryptography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crystal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        crystalline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        crystallization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cube => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        cubicle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cuckold => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cuckoo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cuddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cue => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cuff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cuisine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        culinary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        culminate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        culmination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        culpability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        culpable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        culprit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cult => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cultivate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        cultivated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cultivation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        culture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        culvert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cumbersome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cumulus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cunning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cupboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cupping => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cur => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        curate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curd => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curfew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curiosity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        curl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        curling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        currency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        current => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curriculum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curse => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cursed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cursing => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cursory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curtail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curtailment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curtain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curvature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        curvilinear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cushion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cusp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cussed => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        custodian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        custody => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        custom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        customary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        customer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cutaneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cuticle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cutlery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cutter => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cutters => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        cutthroat => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cutting => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cuttings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cwt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cyanide => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cycle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cyclical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cyclist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cyclone => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        cylinder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cylindrical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cymbal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cynic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cyst => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cystic => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        cytomegalovirus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        cytoplasm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        czar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dabble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dabbling => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dado => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        daemon => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        daft => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dagger => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        daily => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dainty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dairy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        damage => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        damages => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dame => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        damn => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        damnation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        damned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        damp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dampened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        damper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        damsel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        dancer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dandruff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dandy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        danger => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dangerous => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dangle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dank => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dapper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dare => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        daring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        darken => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        darkened => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        darkly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        darkness => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        darling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        darn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dart => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dashboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dashed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dashing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dastardly => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        data => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        database => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        date => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        daughter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dawn => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        day => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        daybreak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        daydreaming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        daze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dazed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dazzling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deacon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        deactivate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deadlock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deadly => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deaf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deafening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deafness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deal => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        dealer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dealing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dealings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        dean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dearth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        death => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        debacle => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        debatable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        debate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        debauchery => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        debenture => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        debit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        debris => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        debt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        debtor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        debut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decanter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decay => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        decayed => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deceased => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deceit => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        deceitful => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deceive => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deceived => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deceiving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        decency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        decent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        deception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deceptive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decidedly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deciduous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decimal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decipher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decisive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        declaration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        declaratory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        declare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        declination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        declining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decompose => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decomposed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        decomposition => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        decorate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decoration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decorum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decoy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        decrease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decreased => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decreasing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decrement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decrepit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        decry => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dedication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        deduce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deduct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        deepen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defamation => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defamatory => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        default => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        defeat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defeated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        defect => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defection => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defective => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defend => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        defendant => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        defended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        defender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        defending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        defense => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        defenseless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        defensible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defensive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        deferral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deferring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defiance => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defiant => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deficiency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deficit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        define => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        definition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        definitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        deflate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deflation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deflect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deflection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defloration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deform => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deformed => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deformity => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        defraud => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        defunct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        defy => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        degeneracy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        degenerate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        degeneration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        degradation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        degrade => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        degrading => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        degree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dehydrated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delay => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        delayed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delectable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        delegate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        delegation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deleterious => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deletion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deliberate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        deliberation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deliberative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delicacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delicious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        delight => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        delighted => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        delightful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        delineate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delineation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delinquency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delinquent => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delirious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        delirium => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deliverance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        delivery => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delta => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deluge => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        delusion => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        delusional => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        delve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demand => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demanding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demeanor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demented => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dementia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        demise => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        democracy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        democrat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demolish => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        demolition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demon => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        demonic => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        demonstrable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        demonstrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demonstrated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demonstrating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demonstration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demonstrative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        demonstrator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        demoralized => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        demos => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        den => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        denomination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denominational => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denominator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denounce => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        density => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dentistry => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denunciation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deny => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        denying => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deodorant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depart => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        departed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        department => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        departure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depend => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        dependant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dependence => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dependency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dependent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        depict => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depicting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depletion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deplorable => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deplore => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deploy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deport => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deportation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deposit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depositary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depository => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        depot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depraved => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depravity => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depreciate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depreciated => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depreciation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        depress => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depressed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depressing => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depression => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depressive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deprivation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        depth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        deputy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        derail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deranged => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        derelict => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        derision => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        derivation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        derivative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        derive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dermal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dermatologist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        dermatology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        derogation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        derogatory => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        descend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        descendant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        descendent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        descending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        descent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        describe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        description => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        descriptive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        desecration => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        desert => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deserted => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        desertion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deserve => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        deserved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        deserving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        design => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        designate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        designation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        designed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        designer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        designing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        desirability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        desirable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        desiring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        desirous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        desist => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        desk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        desolation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        despair => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        despairing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        despatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        desperate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        desperation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        despicable => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        despise => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        despotic => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        despotism => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dessert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        destination => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 0 },
        destined => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        destiny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        destitute => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        destroyed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        destroyer => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        destroying => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        destruction => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        destructive => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detached => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detachment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        details => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detainee => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        detect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        detectable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        detective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detergent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deteriorate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deteriorated => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        deterioration => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        determinable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        determinate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        determination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        determined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        detest => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detonate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        detonation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detract => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detriment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detrimental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        detritus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deuce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devastate => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        devastating => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        devastation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        develop => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        developing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        development => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deviate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deviating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        deviation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        device => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devil => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        devilish => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devoid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devolution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devolve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devotee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devotional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        devour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        devout => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        dew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dexter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dexterity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dextrose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diabolical => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diagnosis => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        diagnostic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diagnostics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diagram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dialect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dialectic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dialogue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diameter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diamond => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        diamonds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diaper => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diaphragm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diarrhoea => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        diatribe => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dichotomous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dichotomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dictate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dictation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dictator => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dictatorial => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dictatorship => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        diction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dictionary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        dictum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        didactic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        die => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        diet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dietary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        differ => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        difference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        differences => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        differential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        differentiation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        differently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        differing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        difficult => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        difficulties => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        difficulty => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        diffuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diffusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        digest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        digestion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        digit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        dignified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dignity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        digress => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        digs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dike => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dilapidated => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dilatation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dilation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dilemma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diligence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        diligent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diluent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dilute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diluted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dilution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dimension => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diminish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        diminished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diminution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diminutive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        din => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dinner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dinosaur => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diocesan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diocese => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diorama => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diploma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diplomacy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        diplomat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diplomatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        dire => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        directed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        direction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        directly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        director => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        directory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dirt => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dirty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disabled => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disadvantage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disaffected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disagree => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disagreeable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disagreeing => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disagreement => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disallow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disallowed => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disappear => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disappearance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disappearing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disappoint => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disappointed => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disappointing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disappointment => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disapproval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disapprove => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disapproved => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disapproving => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disarm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disarray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disaster => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        disastrous => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disband => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disbelief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disbelieve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disburse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disbursement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disc => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discarded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discernible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discerning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discernment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discharge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disciple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        discipline => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disclaim => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        disclaimer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disclose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disclosed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        disclosure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discoloration => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discolored => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        discomfort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disconnect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disconnected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disconnection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discontent => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        discontinuance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discontinue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discontinuity => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        discontinuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discord => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discounted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discourage => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        discouraged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discouragement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discourse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discovery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        discredit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discreet => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        discrepancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discrete => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discretion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        discretionary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        discriminate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        discriminating => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discrimination => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        discus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discuss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        discussion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        disdain => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disease => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        diseased => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disembodied => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disengage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disengagement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disfigured => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disgrace => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disgraced => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disgraceful => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disgruntled => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disguise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disguised => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disgust => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disgusting => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disheartened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disheartening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dishonest => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dishonesty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dishonor => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disillusionment => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disinfect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disinfectant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disinfection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        disinformation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disingenuous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disintegrate => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disintegration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disinterested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disjoint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disjointed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disjunctive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diskette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dislike => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disliked => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dislocated => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dislocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dislodge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dismal => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dismay => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        dismemberment => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dismiss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dismissal => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        dismount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disobedience => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disobedient => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disobey => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disorder => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disorderly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disorganized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disparage => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disparaging => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disparate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disparity => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dispassionate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dispatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dispensation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disperse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispersed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispersion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        displace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        displaced => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        displacement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        display => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        displeased => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        displeasure => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disposal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispose => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disposed => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        disposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispossessed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disprove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dispute => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disqualification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disqualified => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disqualify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disregard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disregarded => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disreputable => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disrepute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disrespect => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disrespectful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disruption => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        dissatisfaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissatisfied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissection => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disseminate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dissemination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissension => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissenting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissertation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disservice => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dissident => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissimilar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissipate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissipated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissociation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissolution => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        dissolve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissonance => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dissuade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distaste => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distasteful => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distillate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distillation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        distinction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        distinctive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distinguish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distinguishable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distinguished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distinguishing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distorted => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distortion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distract => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distracted => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distracting => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distraught => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        distress => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        distressed => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distressing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distribute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distribution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        district => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        distrust => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disturbance => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        disturbed => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        disuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        disused => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ditch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ditto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ditty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        diurnal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        dive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diverge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divergence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divergent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        diverging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diverse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        diversified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        diversify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diversion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        diversity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        diverting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divestment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divided => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dividend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divination => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divinity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        divisible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        division => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divisor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        divorce => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 1 },
        divulge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dizziness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dizzy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        docile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        docked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        docket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doctor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        doctrinal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doctrine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        document => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        documentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dodge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dodging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dogged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dogma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        dogmatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doldrums => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        doll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dollar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dolor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dolphin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        domain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        domestic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        domesticated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        domestication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        domicile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        domiciled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dominance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dominant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dominate => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dominating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        domination => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dominion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        domino => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        don => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        donation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        donkey => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        donor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doodle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doom => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doomed => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        doomsday => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        door => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doorbell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doorway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dormant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dormitory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dorsal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        double => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doubled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doublet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doubling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doubt => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        doubtful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doubting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doubtless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        douche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doughnut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dove => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        downcast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        downfall => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        downhill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        downpour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        downright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        downy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dowry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        doze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dozen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        draft => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dragon => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drainage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drama => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dramatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drapery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drastic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        draught => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        draw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drawback => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drawer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drawers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drawing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dread => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dreadful => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dreadfully => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        dream => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dreamer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dreaming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dreamy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dreary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dredge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drenched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dresser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dribble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dried => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drifted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drinking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dripping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drivel => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        driver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        driveway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drizzle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        droll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drool => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drooping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        droplet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drought => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drown => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        drowsiness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drowsy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drudgery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drugged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        drugstore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        druid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drummer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drumming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drunken => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        drunkenness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dryness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dualism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dubious => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ducking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ductile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        due => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duel => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dues => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dugout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        dull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dumb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dummy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dumps => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dung => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dungeon => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dupe => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duplex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duplicate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duplication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duplicity => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        durability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        durable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        duration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duress => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dusk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dusky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        duster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dusty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dutiful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        dwarf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dwarfed => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dwell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dweller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dwelling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dye => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dying => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dyke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dynamic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        dynamical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dynamics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dynamite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dynasty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        dysentery => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        dyspepsia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eager => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        eagerness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        eagle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        earlier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        early => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        earnest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        earnestly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        earnestness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        earnings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earshot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earthenware => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earthly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        earthquake => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        earthy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        easel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        easement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        easily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        easy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        easygoing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        eat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        eating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eavesdropping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ebb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ebony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eccentric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eccentricity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ecclesiastical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        echo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eclectic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eclipse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ecliptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        economical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        economics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        economy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ecstasy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ecstatic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        ecumenical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eddy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edict => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edification => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        edifice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        edition => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        editor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        editorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        educate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        educated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        education => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        educational => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        eel => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        effects => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effectual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effectually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effectuate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effeminate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        efficacious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        efficacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        efficiency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        efficient => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        effigy => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        effort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        effusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        egg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ego => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        egotistical => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        egregious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        egress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eighth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eighty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ejaculate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ejaculation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        eject => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ejection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elaborate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elaboration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        elan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elapse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elapsed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elastic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elasticity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        elbow => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eld => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        elderly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elders => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        eldest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        election => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        electorate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        electric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        electricity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        elegance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        elegant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        element => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elementary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elements => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elephant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elevate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elevation => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        elevator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eleven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eleventh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elf => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elicit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eligible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        elimination => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        elite => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        elk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ellipse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ellipsis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ellipsoid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elliptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elliptical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elongate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elongation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eloquence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        eloquent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        elucidate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        elucidation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        elusive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        emaciated => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        emanate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emancipation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        embankment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embargo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embarrass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        embarrassing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embarrassment => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        embassy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embellish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embellishment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embezzlement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emblem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emblematic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embodiment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embolism => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        embossed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embrace => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        embroidered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embroidery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embroiled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embryo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        embryonic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emerald => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emerge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emergence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emergency => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        emeritus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        emigrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emigration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eminence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        eminent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        eminently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        emir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        emission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emotion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emotional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emotive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        empathy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        emperor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emphasis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emphasize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        emphatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        empire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        empirical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        empiricism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        employ => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        employer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        employment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emporium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        empower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        empress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emptiness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        emption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        empty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        emulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        emulsion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enablement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enactment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enamel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encampment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enchant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        enchanted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enchanting => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        enchantment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encircle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encircling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enclave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enclose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encompass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        encounter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encourage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        encouragement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        encroach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encroachment => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encrypt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        encumbrance => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        encyclopedia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        end => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endanger => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endangered => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endeavor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endemic => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endless => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        endocarditis => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        endorsement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        endowed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        endowment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        endpapers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endpoint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        endurance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        endure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        enema => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enemy => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        energetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        energy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enforce => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        enforcement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engaged => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        engagement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engaging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        engender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engineer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engineering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engrave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engraved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engraver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engraving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engrossed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engrossing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        engulf => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enhance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        enigma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enigmatic => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enjoin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enjoy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enjoying => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enlarged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enlargement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enlighten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enlightenment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        enlist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enliven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        enmity => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        enormity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enormous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enormously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enrich => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        enroll => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ensemble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ensign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        enslave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enslaved => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        enslavement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ensue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ensure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entangled => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        entanglement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enterprise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enterprising => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        entertain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        entertained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        entertaining => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        entertainment => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        enthusiasm => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        enthusiast => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        entice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entirety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entitle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entomology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entrails => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entrance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entreat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entrepreneur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        entrust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        entry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enumerate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        enumeration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        envelope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        envious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        environ => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        environment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        environs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        envision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        envoy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ephemeral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ephemeris => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        epic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        epidemic => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        epidermis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        epilepsy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        epilogue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        episcopal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        episode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        episodic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        epistle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        epitaph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        epithet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        epitome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        epoch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        equalization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equalize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        equate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equatorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equestrian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equidistant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equilibration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equilibrium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        equip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equipment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        equivalence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equivalent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        equivocal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        era => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eradicate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eradication => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erase => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erasure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ergo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erosion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erotic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        err => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        errand => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        errant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erratic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        erratum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erroneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        error => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        erst => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        erudite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        erupt => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        eruption => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        escalade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        escalate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        escalator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        escape => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        escaped => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        escarpment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eschew => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        escort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        esoteric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        especial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        espionage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        espouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        esprit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        essay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        essayist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        essence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        essential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        essentially => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        establish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        established => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        establishment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        estate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        esteem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        esthetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        estimate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        estimation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        estoppel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        estranged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        estrogen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        estuary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        etch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        etching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eternal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eternity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ethanol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ether => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ethereal => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ethical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ethics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ethnography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        etiology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        etiquette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        etymology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        euchre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eugenics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eulogy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        euphemism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        euthanasia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        evacuate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evacuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evade => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evaluate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evanescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        evangelical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evangelist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evangelistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evaporation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evasion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        eve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        event => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eventful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eventual => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eventuality => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evergreen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        everlasting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        evermore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        everyday => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evict => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        eviction => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        evidence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        evil => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        evoke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        evolution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        evolve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ewe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exacerbate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exacerbation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exacting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exaggerate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exaggerated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exaggeration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exalt => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        exaltation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        exalted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        exam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        examination => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        examine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        examiner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exasperation => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excavate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excavation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        excavator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exceed => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exceeding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excel => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        excellence => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        excellent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        excepting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excerpt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excessive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excessively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exchange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        excise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excitability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        excitation => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        excite => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        excited => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        excitement => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        exciting => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        exclaim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        excluded => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        excluding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        exclusion => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        excrement => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excretion => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excruciating => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excursion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        excuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        execute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        execution => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        executioner => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        executive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        executor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        exegesis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exemplar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exemplary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exemplify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exempt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exemption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exercise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exertion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exhale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exhaust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exhausted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        exhaustion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        exhaustive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        exhibit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exhibition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exhilaration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        exhort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exhortation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exigent => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        exile => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        exist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        existence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        existent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        existing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exodus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exorbitant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exorcism => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        exorcist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exotic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        expand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expanded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expanse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expansion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expansive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expatriate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expect => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        expectancy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expectant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expectation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        expected => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expecting => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expediency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expedient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        expedite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expedition => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        expeditious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expel => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        expenditure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expenses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expensive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        experience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        experienced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        experiences => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        experiment => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        experimental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        experimenter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        expertise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        expiration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        expired => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expiry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        explanation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explanatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expletive => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explode => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        exploit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explore => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explorer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        explosion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        explosive => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        exponent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exponential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        export => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exportation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expose => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exposed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expository => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exposure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        express => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expression => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expressive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expropriation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        expulsion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        exquisite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exquisitely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        extant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        extendable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extension => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extensive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        extent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exterior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exterminate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        extermination => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        external => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        externally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extinct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        extinguish => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extra => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        extract => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extracting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extractor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extradition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extrajudicial => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extramural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extraneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extraordinary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        extravaganza => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extreme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extremely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extremity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extricate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        extrinsic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        extrusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        exuberance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        exude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eye => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eyeglass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eyelet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eyepiece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eyesight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        eyewitness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        fable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fabric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fabricate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fabricated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fabrication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        facade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        face => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        facet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        facile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        facilitate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        facility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        facing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        facsimile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        faction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        factor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        factory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        facts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        faculties => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        faculty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        faded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        faeces => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        failing => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        failure => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fain => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fainting => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        fair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fairly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fairway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fairy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        faith => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        faithful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        faithless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fallacious => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fallacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fallible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fallow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falsehood => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        falsely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falsification => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falsified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falsify => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falsity => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        falter => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fame => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        famed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        familiar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        familiarity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        familiarize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        famine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        famous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        famously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fanatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fanaticism => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fanciful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fancy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fandango => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fanfare => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        fang => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fangs => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fanning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fantasia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fantasy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farcical => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farewell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farm => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farmer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farmhouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        faro => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        farther => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fascia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fascinating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fascination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fashion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fashionable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fasten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fastener => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fastening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fasting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fat => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fatal => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fatality => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        father => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        fathom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fatigue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fatigued => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fatty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fault => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        faultless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        faulty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fauna => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        favor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        favorable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        favorite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        favoritism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fawn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fear => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fearful => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fearfully => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        fearing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fearless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        feasibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feasible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feat => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        feather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        features => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        febrile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fecal => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feces => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fecundity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        federal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        federation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fee => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feeble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        feed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feeder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feeling => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        feet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feigned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        felicity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        feline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fellow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fellowship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        felon => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        felony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        felt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        female => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        feminine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        femininity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feminist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fenced => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        fennel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ferment => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fermentation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ferocious => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ferocity => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ferry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fertile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fertilize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fervent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fervor => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        festival => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        festive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fetch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fete => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        fetish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feud => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feudal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feudalism => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fever => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        feverish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiancee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiasco => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fib => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fibrous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fickle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fictitious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiddler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fidelity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fiduciary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        field => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiend => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fierce => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fiesta => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        fight => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fighter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fighting => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        figment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        figurative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        figure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        figurine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filamentous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        file => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filibuster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filigree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        fillet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        film => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filmy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filth => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        filthy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        final => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finally => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        finance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        financial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        financier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        find => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        finesse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        finger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fingerprint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        finite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fire => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firearms => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fireball => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        firefly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fireman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        fireplace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fireproof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fireside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firewood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firework => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firmament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firmly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        firmness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        firstborn => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fiscal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fisherman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fishery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fishing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fishy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fissile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fissure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fistula => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fitness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fits => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fitted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fitting => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fittings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fixation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fixed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        fixture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fixtures => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fizz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flabby => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flaccid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        flagging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flagrant => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flagship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        flake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flaky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flame => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flaming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        flank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flanked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flanking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flannel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flapping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flaring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flashback => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flashing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flashlight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flashy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flask => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flatness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flatten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flattering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        flattery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flatulence => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flaunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flavor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flaw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        flea => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fled => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flee => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fleece => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fleet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fleeting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flesh => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fleshy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flexibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        flexible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flexion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flicker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flickering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flinch => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        fling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flipper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flirt => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        flirting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        float => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flog => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        flood => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        floor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flop => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        flora => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        floral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        florist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        floss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flounder => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        flour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        flowering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flowery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        flu => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluctuate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluctuating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluctuation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluffy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        fluorescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluorescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flurry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        flustered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fluvial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flux => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flyer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        flying => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        flywheel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foaming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foamy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fob => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        focal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        focus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fodder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foe => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foggy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foiled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        folded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foliage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        folio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        folk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        folklore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        follicle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        follicular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        follow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        follower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        folly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fondling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fondness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        font => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        food => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fool => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fooling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foolish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foolishness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        football => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        footbridge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        footing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        footpath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        footprint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foray => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forbearance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forbid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        forbidding => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        force => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forced => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forceps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forcibly => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ford => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forearm => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreboding => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forecast => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        forecaster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreclose => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        forefathers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        forefinger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forego => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foregoing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        foregone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreground => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forehead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreigner => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forensic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forerunner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        foresee => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        foreseen => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        foresight => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        forest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forethought => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forewarned => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foreword => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forfeit => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        forfeited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forfeiture => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        forge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forgery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forget => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forgetful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forgetfulness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forgive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forgiven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forgiving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        forgotten => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forlorn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        form => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formalism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        formation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        formed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formidable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forming => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formula => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        formulary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        formulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fornication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forsake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        forsaken => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        forsooth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        forte => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forthcoming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        forthwith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fortification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fortify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fortitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fortnightly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fortress => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        fortuitous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fortunate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fortune => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        forty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        forward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fossil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fossils => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foul => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        found => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        foundation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        founder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foundry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fountain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fourfold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fourth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fowl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        foxy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fractional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fracture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fragile => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fragility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fragment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fragmentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fragrance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fragrant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        frailty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        framework => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        franchise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        frankness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        frantic => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        fraternal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fraternity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fraud => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fraudulent => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fraught => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frayed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        freak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freakish => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        freedom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        freehold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freelance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        freeway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freeze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freezer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freezing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frenetic => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        frenzied => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frenzy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frequency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frequent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frequently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fresco => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        freshman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fret => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        friction => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        friend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        friendliness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        friendly => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        friendship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        frigate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fright => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        frighten => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        frightened => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        frightful => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        frigid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fringe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fringed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frisky => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        frivolous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frolic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        front => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frontage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frontal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frontier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fronting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frontispiece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frostbite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frosted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frosty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        froth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frothy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        frowning => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        frozen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frugal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fruit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fruitful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fruition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fruitless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        frustrate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        frustrated => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        frustration => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fudge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fuel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fugitive => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        fulcrum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fulfill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fulfillment => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        full => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fullness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fully => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fumble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fumigation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fuming => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fun => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        function => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        functional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fund => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fundamental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fundamentally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        funds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        funeral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fungus => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        funk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        funnel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furiously => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furlough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furnace => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furnish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furniture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furor => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        furrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        furtherance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fury => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        fusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        fuss => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        fussy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        futile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        futility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        future => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fuzz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        fuzzy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gaby => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gag => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        gaggle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gain => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gainful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gaining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gait => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gala => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        galaxy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gall => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gallant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gallantry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gallery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        galley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gallop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        galloping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gallows => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        galore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        galvanic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gamble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gambler => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        gambling => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        game => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gaming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gammon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gamut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gang => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gaol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        gaping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garbage => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garbled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gardener => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gardening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garish => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        garlic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garnet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        garnish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        garrison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        garter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gas => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gaseous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gash => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gasification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gasoline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gasp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        gasping => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gastric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gastronomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        gateway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        gather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gatherer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gathering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gauche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gauge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gauging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        gaunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gauntlet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gauze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gavel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gawk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        gaze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gazebo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gazelle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gazette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        gazetteer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gelatin => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        geld => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gelding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gemini => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        genealogy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        general => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        generality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generalization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        generosity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        generous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        genesis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        genetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        genetics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        genial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        genital => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        genius => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        genre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gent => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        genteel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gentleman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        gentleness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gentry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        genuine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        genus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        geography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        geology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        geometry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        geranium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        geriatric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        germ => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        german => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        germane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        germinate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        germination => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gestation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gesture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ghastly => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ghetto => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ghost => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ghostly => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        giant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gibberish => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gift => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        gifted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gigantic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        giggle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gills => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gilt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gimp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ginger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gingerbread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gingerly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        giraffe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        girder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        girdle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        girl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        girth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        giving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glabrous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glacial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glacier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glad => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gladiator => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gladness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glare => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glaring => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glasses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glassware => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glaze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gleam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glide => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glimmer => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        glimpse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glitter => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glittering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        globe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        globular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gloom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        gloomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        glorification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glorify => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        glory => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        gloss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glossary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glossy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glow => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        glowing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        glucose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        glut => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gluten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gluttony => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        glycerin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gnat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gnome => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goatee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gob => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gobble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goblet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goblin => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        god => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        goddess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        godfather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        godless => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        godly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        godsend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        goggle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goggles => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        golden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        golf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gondola => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gonorrhea => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        goo => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        good => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        goodbye => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goodly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        goodness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        goods => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        goodwill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        goody => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gooey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        goose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gopher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gore => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        gorge => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gorgeous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gorilla => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gory => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        gospel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        gossip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gouge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gourmet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        govern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        governess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        governing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        government => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        governor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        gown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grab => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        graceful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gracious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        graciously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gradation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grader => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gradient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gradual => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gradually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        graduation => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        grain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grammar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        grand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grandchildren => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        grandeur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        grandfather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        grandiose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grandmother => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        grange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        granite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        granted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        grantee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grantor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        granular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        granule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grapes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        graphics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grapple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grasp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grasping => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grasshopper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grassy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grated => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grateful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gratify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        grating => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gratis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gratitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gratuitous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gratuity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grave => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        gravel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        graver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gravitate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gravitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gravity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gravy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gray => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        graze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greasy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        greatest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greatly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greatness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        greed => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greedy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        green => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        greenhouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greenish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greenwood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greeting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        gregarious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        grenade => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        greyhound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gridiron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        grievance => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        grieve => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        grievous => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        griffin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grille => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grim => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        grime => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grimy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grin => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        grind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grinder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grinding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grisly => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        grit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        gritty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grizzly => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groan => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        grocer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groceries => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grocery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groggy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grope => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gross => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grotesque => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grotto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ground => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        grounded => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        groundless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grounds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        groundwork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        group => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grouping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grow => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        growl => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        growling => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        growth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        grub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grudge => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grudgingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gruesome => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gruff => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grumble => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        grumpy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        grunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guarantee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guaranty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guard => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guarded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        guardian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guardianship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gubernatorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guerilla => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        guesswork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guidance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guidebook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        guild => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guillotine => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        guilt => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        guilty => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        guinea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guitar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gules => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gulf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gullible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        gully => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gulp => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        gum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gummy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gun => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gunner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gunpowder => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guru => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        gush => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 1, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gusset => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        gust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gusty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gut => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gutter => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        guzzling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gymnasium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gymnast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        gymnastic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gymnastics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gynecology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gypsy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        gyroscope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        habit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        habitat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        habitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        habitual => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        habitually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hacienda => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hag => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haggard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        haggle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        hair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hairy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        half => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        halfway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hallowed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hallucination => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        halo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        halt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        halter => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        halting => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        halve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        halving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ham => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hamlet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hammer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hammering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hammock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hamper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hamstring => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handbook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        handful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handicap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        handicraft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handiwork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handkerchief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handsome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handwriting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        handy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hang => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hangar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hanging => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hangman => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hangout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hankering => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hap => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        haphazard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        happen => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        happening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        happily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        happiness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        happy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        harass => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harassing => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harbinger => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harbor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        harden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hardened => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hardening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hardness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hardship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hardware => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hardy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        hare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harlot => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harm => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harmful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        harmonica => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harmonics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harmoniously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        harmonize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harmony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        harness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harpsichord => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harrowing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harry => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        harshness => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        harvest => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hashish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haste => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hasten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hastily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hasty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hatchet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hate => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hateful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hating => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hatred => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        haughty => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haul => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haulage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haunt => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haunted => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        haven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        havoc => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hawk => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hawking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hazard => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hazardous => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        haze => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hazy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        head => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headache => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headdress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        header => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headgear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headlight => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headlong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headquarters => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headstone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        headway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        heady => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        healing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        health => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        healthful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        healthy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        heap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hearer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hearing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hearsay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hearse => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        heart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heartache => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        heartburn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heartfelt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        hearth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        heartily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        heartless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hearts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heartworm => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heathen => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heavenly => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        heavens => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        heavily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heaviness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heaving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hectares => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hectic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hedge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hedgehog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hedonism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        heed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heels => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heft => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hegemonic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heifer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        height => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heighten => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heinous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heiress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heirloom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heirs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        helical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        helix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hell => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hellish => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        helm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        helmet => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        helper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        helpful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        helpless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        helplessness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hematite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hemi => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hemisphere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hemispheric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hemlock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hemorrhage => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hemorrhoids => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hemp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        henceforth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herald => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heraldry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herbaceous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herbal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        herbarium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herd => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hereditary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heredity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heresy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heretic => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heretical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heretofore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hereunto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herewith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heritage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        hermaphrodite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        hermeneutics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hermit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        hernia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hero => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        heroic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        heroics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        heroin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heroine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        heroism => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        herpes => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        herpesvirus => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hesitating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hesitation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heterogeneity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hexagon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        heyday => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        hiatus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hibernate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hibernation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hiccup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hidden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hide => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hideous => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hiding => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hierarchical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        high => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        higher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        highest => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        highland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        highlands => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        highway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hiker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hilarious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        hilarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hilly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hilt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hindering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hindrance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hinge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hinterland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hippie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hire => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        hirsute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hiss => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hissing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        histology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        historian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        historic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        historiography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        history => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hit => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hitherto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoarse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hoax => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        hob => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hobby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hobo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hockey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hog => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        holder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        holding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        holiday => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        holiness => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        hollow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        holocaust => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        holy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        homage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        homeless => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        homeopathic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homeopathy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homesick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        homestead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homework => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homicidal => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homicide => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        homily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homogeneity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homogeneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homologous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homologue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        homosexual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        homosexuality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        honest => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        honesty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        honey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        honeycomb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        honeymoon => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        honeysuckle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        honor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        honorable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        honorarium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hood => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hooded => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hooked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hooker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoot => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hope => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        hopeful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        hopeless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hopelessness => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hopes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hopper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horde => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        horizon => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        horizontal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horizontally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hornet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horoscope => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horrible => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horribly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horrid => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        horrific => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        horrified => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horrifying => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        horror => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        horrors => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        horse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        horseman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horseshoe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horticultural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        horticulture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hosiery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hospice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hospital => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        hospitality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hostage => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hostel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hostile => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hostilities => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hostility => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hot => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hotbed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hotel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hourglass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hourly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        house => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        household => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        householder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        housekeeper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        housekeeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        housewife => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        housing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hovercraft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        howl => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        howsoever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hoy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        huddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        huff => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        huge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hulk => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        human => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        humanitarian => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        humanities => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humanity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        humble => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        humbled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        humbly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        humbug => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        humid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humiliate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        humiliating => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humiliation => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        humility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        hummer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hummingbird => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humongous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        humorist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        humorous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hunch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hundred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hundredth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hunger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hungry => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hunk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hunks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hunter => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hunting => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hurl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hurrah => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hurricane => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hurried => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hurry => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hurt => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hurtful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hurting => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        husbandry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        hush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hushed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        husk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        husky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hustle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hustler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        hutch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hyacinth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hybrid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hydra => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hydraulics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hydrocephalus => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        hydrodynamics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hydrogen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hydrographic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hydrology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hygiene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hygienic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        hymn => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        hype => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hyperbole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypertrophy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        hyphen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypnotic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypnotized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypocrisy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypocrite => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypocritical => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hypothesis => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        hypothetical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hysteria => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        hysterical => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iceberg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        icon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iconic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iconography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        icy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idealism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        idealist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        identical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        identically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        identification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        identify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        identity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ideology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idiocy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        idiom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idiomatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idiot => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idiotic => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idleness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        idol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        idolatry => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        igloo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        igneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ignite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ignition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ignorance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ignorant => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ignore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ilk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ill => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        illegal => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        illegality => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illegally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illegible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illegitimate => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        illicit => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illiterate => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        illogical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illuminate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        illumination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        illuminator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        illustrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        illustration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illustrative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        illustrious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        image => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imagery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imaginary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imagination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imaginative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        imagine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imagined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imagining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imbedded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imitate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imitated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immaculate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        immaterial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immature => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immaturity => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immeasurable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immeasurably => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immediacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        immediately => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        immemorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        immerse => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        immersion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immigrant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immigration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imminent => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immoral => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        immorality => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immortal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        immortality => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immovable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        immune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immunity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        immunization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        immutable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impairment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        impartial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        impartiality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        impassable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impassioned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impatience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impatient => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impeach => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impeachment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impeccable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        impede => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impediment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impelled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impending => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impenetrable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        imperative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imperceptible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imperfection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imperfectly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imperial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impermeable => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impermissible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impersonal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impersonate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impersonation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impervious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        impetus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implacable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implantation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implanted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implicate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implicated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        implosion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impolite => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        import => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        importance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        important => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        importation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imposing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impossibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impossible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        impotence => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        impotent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impracticable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        impression => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        impressionable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        imprint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imprison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imprisoned => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        imprisonment => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        improbable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impromptu => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impropriety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        improve => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        improved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        improvement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        improving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        improvisation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        improvise => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        improvised => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imprudent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        impulse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impunity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impure => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        impurity => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        imputation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inaccessible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inaccurate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inactivate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inactivation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inactive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inactivity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inadequacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inadequate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inadmissible => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inadvertent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inadvertently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inalienable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inanimate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inapplicable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inappropriate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inattention => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inaudible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inaugural => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inaugurate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inauguration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        inborn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inbred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incalculable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incandescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incapable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incapacity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incarceration => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incase => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incendiary => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        incense => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incentive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incessant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incessantly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incest => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incestuous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incidence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        incidentally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incineration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incipient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incisive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        incite => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incitement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inclement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inclination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        inclined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        include => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        included => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        including => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inclusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        inclusive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        incognito => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incoherent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        income => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        incoming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incompatible => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incompetence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incompetent => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incompletely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incompleteness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incomprehensible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inconclusive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incongruous => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inconsequential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inconsiderate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inconsistency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inconspicuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incontinence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        inconvenient => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incorporate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incorporation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incorrect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        increase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        increased => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incredulous => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        increment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incrimination => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incubation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incubus => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        incurable => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        incursion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indebted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indecency => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indecent => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indecision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indecisive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indefensible => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indelible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        indemnification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indemnify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indemnity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        indent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        indentation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indenture => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        independence => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        independent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indescribable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indestructible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        indeterminate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        index => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indicating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indicative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indicator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indict => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indictment => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indifference => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        indigenous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indigent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        indigestion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indignant => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indignation => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indigo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indirect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indispensable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indistinct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indistinguishable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        individuality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        indivisible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        indoctrination => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indolent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indomitable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        indoor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        induce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        induced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inducement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        induction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indulge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indulgence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        indulgent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        industrious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        industry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ineffable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ineffective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ineffectual => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inefficiency => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inefficient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inelastic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ineligible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inept => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ineptitude => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inequality => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inequitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inertia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inevitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inexact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inexcusable => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inexhaustible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inexpensive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inexperience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inexperienced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inexplicable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        infallibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        infallible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        infamous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infamy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        infancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infant => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        infanticide => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        infantile => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infantry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infarct => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        infatuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infeasible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infect => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infection => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infectious => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        infer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inferential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inferior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inferiority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inferno => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infertile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infertility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        infestation => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infidel => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infidelity => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        infiltration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        infinite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        infinitely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infinitesimal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infinity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        infirm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infirmary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infirmity => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inflammation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inflated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inflation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inflection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inflict => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        infliction => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inflorescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        influence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        influential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        influenza => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        influx => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        informal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        informant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        information => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        informed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        informer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infraction => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infrequent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        infrequently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infringement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infused => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        infusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingenious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ingenuity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingestion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingrained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingredient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ingress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhabit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhabitant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhabited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhabiting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhalation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inherent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inherit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inheritance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        inhibit => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inhibition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inhospitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inhuman => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inhumanity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inimical => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inimitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        iniquity => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        initial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        initiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        initiated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        initiative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inject => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        injection => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        injunction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        injure => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        injured => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        injurious => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        injury => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        injustice => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inkling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inlay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inlet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inmate => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        innate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        innermost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        innings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        innkeeper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        innocence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        innocent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        innocently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        innocuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        innovate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        innovation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        innuendo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        innumerable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inoculation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        inoperative => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inordinate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inorganic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inquest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inquire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inquirer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inquiring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inquiry => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inquisitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        insane => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insanity => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        inscription => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inscrutable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insecure => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        insecurity => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inseparable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        insert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inserted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insertion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insidious => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insignia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        insignificance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insignificant => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        insipid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insolent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insoluble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insolvency => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        insolvent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        inspect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inspector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inspiration => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inspire => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        inspired => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        instability => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        install => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        installation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        installment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instantaneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instantaneously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instigate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instigation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instinct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instinctive => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        institute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        institution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instruct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        instructed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instruction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        instructional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instructions => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        instructive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instructor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        instrument => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instrumental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        instrumentalist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        instrumentality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insufficiency => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insufficient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insufficiently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        insult => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        insulting => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        insurance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        insurgent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        insurmountable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        insurrection => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        intangible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        integer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        integral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        integrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        integration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        integrity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        intellect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intellectual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intelligence => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        intelligent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        intelligibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intelligible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        intended => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intense => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        intensely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intensify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intensity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intentional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intentionally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        interaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intercede => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        intercept => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intercession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        interchange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interchangeable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interchanged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intercom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intercourse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        interdependence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interdependent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interdiction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        interested => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        interesting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        interference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interferometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interim => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interior => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        interlocutory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        interlude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intermediary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intermediate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        interminable => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intermission => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intermittent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        internal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        internally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        international => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interpolate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interpolation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interpret => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interpretation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interpreter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interrelated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interrogate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interrogation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interrupt => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        interrupted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        interruption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intersect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intersection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interstitial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intervening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intervention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        interview => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interviewer => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        interworking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intestate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intestinal => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intestine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intestines => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intimacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intimate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        intimately => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intimation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intimidate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intimidation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intolerable => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intolerance => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intolerant => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        intonation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intoxicated => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intoxication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intractable => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intramural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intrepid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intricate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intrigue => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        intriguing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intrinsic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intrinsically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        introduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        introductory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        introspection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        introspective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intruder => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        intrusion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        intrusive => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        intuition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        intuitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        intuitively => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inundation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invade => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        invader => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        invalid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        invalidate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invalidation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invalidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invaluable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invariably => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        invasion => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inventive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inventor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        inventory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inverse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inversely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inversion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inverted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        investigate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        investigation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        investigator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        investor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invigorate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        invincible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invisibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invisible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invitation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        invite => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        inviting => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        invocation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        invoice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        invoke => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        involuntary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        involution => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        involvement => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        inwards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iota => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ire => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iridescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iris => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ironic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irradiation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrational => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrationality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irreconcilable => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        irreducible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        irrefutable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        irregular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irregularity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irregularly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrelevant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irreparable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        irrepressible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irresistible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrespective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irresponsible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irreverent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irreversible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrevocable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrigate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irrigation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irritability => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irritable => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irritating => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        irritation => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        island => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        isle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        islet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        isolate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        isolated => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        isolation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        isomorphism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        isothermal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        issue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        itch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        itching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        item => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        itemize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        items => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iterate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iteration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        iterative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        itinerant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        itinerary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ivory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jab => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jabber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jackass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jackpot => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        jacks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jagged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jaguar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jail => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        jam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        jammed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        janitor => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        japan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jargon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jarring => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        jasper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jaundice => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jaunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        javelin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jaw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jaws => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jealous => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jealousy => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        jeans => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jeep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jelly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jenny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jeopardize => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jeopardy => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jerk => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        jersey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        jester => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jetty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jewel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jeweler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jewelry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jiffy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jimmy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jingle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        job => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        jock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jockey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        john => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        join => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        joined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        joining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        joint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jointly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        joke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        joker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        joking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        jolt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        jornada => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        journal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        journalism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        journalist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        journey => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        journeyman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        jovial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        joy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        joyful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        joyous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        jubilant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        jubilee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        judge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        judging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        judgment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        judicial => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        judiciary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        judicious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        jug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juggle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juggling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juicy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jumble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jumbled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jumbo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        junction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juncture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jungle => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        junior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        junk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        junta => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juridical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jurisdiction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jurisprudence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        jurist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        jury => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        justice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        justifiable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        justification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        justify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        jute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juvenile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        juxtaposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kaiser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kaleidoscope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kangaroo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kanji => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        karma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kayak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        keel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        keeper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        keeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        keepsake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        keg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        kennel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        kern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kernel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kerosene => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kettle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        key => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        keyhole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        keynote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        keystone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        khaki => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        khan => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        kick => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kicking => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kidding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kidnap => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        kill => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        killing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        kiln => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kilogram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kilometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kilt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kimono => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        kindergarten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kindness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        kindred => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        kinematics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        king => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        kingdom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kinky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kiosk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kirk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kiss => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        kit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kitchen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kite => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kitten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        knack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        knapsack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kneel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kneeling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knell => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        knickers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        knife => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        knit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knob => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knoll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knotted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knowing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        knowingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        knowledge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        knuckle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kos => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kris => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        kudos => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        label => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        labor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        laboratory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        labored => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        laborer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laboring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laborious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        labyrinth => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lac => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lace => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        lack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lacking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lackluster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lacquer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lacrosse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ladder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ladle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lady => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lagging => { anger => 1, anticipation => 1, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lagoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lama => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lamb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lament => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lamenting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lamina => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laminated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lamp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lancer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        land => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        landed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        landing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        landlocked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        landlord => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        landmark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        lands => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        landscape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        landscaping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        landslide => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        language => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        languid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        languish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        languishing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lanky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lantern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lapel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lapse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lapsed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        larceny => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        larder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        large => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        larger => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 1 },
        largo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        larva => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        larynx => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lash => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lasso => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lasting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        latch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        late => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lateness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        latent => { anger => 1, anticipation => 1, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        lateral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laterally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        latex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lathe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        latitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        latrines => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lattice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laudable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        laugh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        laughable => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laughing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        laughter => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        launch => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        laundry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        laureate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        laurel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        laurels => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lava => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lavage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lavatory => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lavender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lavish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        law => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        lawful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lawlessness => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lawn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lawsuit => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        lawyer => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        laxative => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        layer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        layered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        layman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lazy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        leader => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        leading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        leads => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leaf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leaflet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leafy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        league => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        leak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leakage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leaky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leaned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leaning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        leap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        learn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        learned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        learner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        learning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lease => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leathery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        lecture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lecturer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ledge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ledger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leech => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leeches => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leer => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        lees => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leeway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        left => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        legality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legalize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legalized => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        legally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legendary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        legibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        legible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        legion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legislate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legislation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legislative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legislator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        legislature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        legitimacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        legs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        legume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leisure => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        leisurely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lemma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lemon => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        lending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        length => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lengthen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lengthened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lengthening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lengthwise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lengthy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leniency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lenient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lens => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leopard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leprosy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lesbian => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lesbianism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lessee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lessen => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lessening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lesser => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lesson => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lessor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lethal => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lethargic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lethargy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        letter => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lettered => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        letters => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lettuce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leukemia => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        levee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        level => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        leverage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        levy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lewd => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lexicon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liabilities => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liaison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liar => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        libel => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        libelous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liberal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        liberalism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liberate => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        liberation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        liberty => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        libido => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        librarian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        library => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        libretto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        license => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lichen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lick => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lie => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        liege => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lien => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lieu => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lieutenant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        life => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lifeblood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lifeboat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lifeless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lifelike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lifelong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lifetime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ligament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ligation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        light => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lighten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lighthouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lightness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lightning => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        likelihood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        likeness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        likewise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lilac => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limbo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limited => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        limitless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limousine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        limp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        line => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lineage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lineal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        linear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        linen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lines => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        linger => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lingo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lingual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        linguist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        linguistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        linguistics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        link => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        linoleum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lipstick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquefaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquefied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liqueur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquidate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquidation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquidator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liquor => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lisp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        list => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        listen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        listener => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        listing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        listless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        litany => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        literally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        literary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        literature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lithe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lithograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lithography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lithology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lithosphere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        litigant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        litigate => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        litigation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        litigious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        litter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        littoral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        liturgy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        livelihood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        livery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        livid => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        living => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        llama => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        load => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loaf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loafer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loath => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loathe => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loathing => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loathsome => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lobby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lobbyist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lobe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        local => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        localization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        localize => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        location => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locksmith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lockup => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        locomotion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locomotive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        locust => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lodge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lodger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lodging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        loft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lofty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        log => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        logarithm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        logarithmic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        logic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        logical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        logistics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        logotype => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lollipop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        loneliness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lonely => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lonesome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        long => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        longevity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        longing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        longitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        longitudinal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        longitudinally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loo => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lookout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loom => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        looming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loon => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loophole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loosen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loosening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lopsided => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lord => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lords => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lordship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lorry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lose => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        losing => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        loss => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lotion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lots => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lottery => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lotto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loudly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        loudness => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lounge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        louse => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lovable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        love => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lovely => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        lovemaking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lover => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        loving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lowering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lowest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lowlands => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lowly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        loyal => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        loyalty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        lubricate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lubrication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luck => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        lucky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        ludicrous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luggage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lull => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lullaby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lumbar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lumber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lumbering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luminescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luminous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lumpy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lunacy => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lunar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lunatic => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lunch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luncheon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lunge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        lungs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lurch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lurid => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lurk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lurking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luscious => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lush => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lust => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lustful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lustrous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lusty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        luxuriant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        luxurious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        luxury => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lying => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lymph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lymphatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lynch => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        lynx => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lyre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        lyric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        lyrical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mace => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        machine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        machinery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        machinist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mackerel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mad => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        madam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        madame => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        madden => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        madman => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        madness => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mafia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magazine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mage => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magenta => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maggot => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magical => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        magician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        magistrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magnate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magnet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        magnetism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        magnetite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        magnificence => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        magnificent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        magnifier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magnify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magnitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        magpie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maiden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mail => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        main => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mainland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mainstay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        maintenance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        majestic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        majesty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        major => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        majority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        make => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        makeshift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        makeup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malady => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malaise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        malaria => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        male => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malevolent => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        malfeasance => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malformation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malice => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malicious => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        malign => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malignancy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        malignant => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malleable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mallet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        malpractice => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mamma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        mammal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mammoth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        man => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        management => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        manager => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mandamus => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mandarin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        mandate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mandible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mandolin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mandrel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maneuver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maneuvering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mange => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mangle => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mango => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mangosteen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manhood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mania => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maniac => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maniacal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manicure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manifest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manifestation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manifested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        manifestly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manifesto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manifold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manipulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manipulation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mankind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        manna => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        manner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mannered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        manners => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        manor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mansion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manslaughter => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        mantle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        manufacture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manufacturer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        manure => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        manuscript => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        map => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marbled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marbles => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        march => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        margin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        marginal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marijuana => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        mariner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maritime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        market => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marketable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        marketplace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marmalade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maroon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marquee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marquis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        marriage => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        married => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        marry => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        marsh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        marshal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        mart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        martial => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        martingale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        martyr => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        martyrdom => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        marvel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        marvelous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        marvelously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        masculine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        masculinity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mask => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        masochism => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mason => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        masquerade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        massacre => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        massage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        massive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        master => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mastermind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        masterpiece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mastery => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        masturbate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        masturbation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        match => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matchmaker => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        material => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materialism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materialist => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materialistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materiality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materialize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materially => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materials => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        materiel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maternal => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        maternity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mathematical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        mathematician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mathematics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matriculation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matrimony => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        matrix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        matted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        matting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mattress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maturation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maturity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mausoleum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mauve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        maxim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        maximum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mayor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        maze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meadow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        meal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meandering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meaning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meaningless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        means => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meantime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        measles => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        measurable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        measure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        measured => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        measurement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        measuring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mechanic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mechanical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mechanism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        medal => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        medallion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        medallist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meddle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meddling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        media => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        medial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        median => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mediate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        mediation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mediator => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        medical => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        medicinal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        medicine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        medieval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mediocre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mediocrity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meditate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        meditation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meditative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mediterranean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        medium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        medley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        meek => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        meet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meeting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        melancholic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        melancholy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        melee => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        melodious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        melodrama => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        melodramatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        melody => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        melt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meltdown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        melting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        member => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        membrane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memento => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        memo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memoir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memorabilia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memorable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        memorandum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memorials => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        memorize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        memory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        menace => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        menacing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        menagerie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        menial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meniscus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        menses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        menstrual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mentor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        menu => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mercantile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mercenary => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        merchandise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        merchant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        merciful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        merciless => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mercurial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mercy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        merge => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        meridian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meridional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        merit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        meritorious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        mermaid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        merriment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        merry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mesa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mesh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meshes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mesmerized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mess => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        message => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        messenger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        messy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metabolism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metallurgy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metamorphosis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metaphor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metaphorical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metaphysical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metaphysics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metastasis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meteor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meteoric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meteorite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meteorological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meteorology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        methanol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        method => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        methodical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        meticulous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metrical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metrology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metropolis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        metropolitan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mettle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mica => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microbe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microbiology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microcosm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microgram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        micrometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        micron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microphone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microscope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        microscopic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microscopically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        microscopy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midday => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        middle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        middleman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midnight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midst => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midsummer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        midwife => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        midwifery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mien => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mighty => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        migrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        migration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        migratory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mildew => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mileage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        milestone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        militant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        military => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        militia => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        milk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        milky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mill => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        millennium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        milligram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        millimeter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        million => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        millionaire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mimic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mimicking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mimicry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        mind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mindful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mindfulness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mineral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mineralogy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mingle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mingled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miniature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minibus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minimize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minimum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minister => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ministerial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ministry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        minivan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minnow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minstrel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minuscule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        minutiae => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miracle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        miraculous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        mirage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mire => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mirror => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mirth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        misappropriation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misbehavior => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        miscarriage => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        miscellaneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miscellany => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mischief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mischievous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misconception => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misconduct => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misdemeanor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miserable => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        miserably => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        misery => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        misfortune => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        misguided => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mishap => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        misinformed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misinterpretation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mislead => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        misleading => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mismanagement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mismatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mismatched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misnomer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misplace => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misplaced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misrepresent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misrepresentation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        misrepresented => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        missile => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        missing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        missionary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        misstatement => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mistake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mistaken => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mister => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mistress => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mistrust => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misunderstand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        misunderstanding => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        misuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mite => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        miter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mitigation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mixed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mixture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moan => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        moat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        mob => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mobile => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mobility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mobilization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mobilize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mockery => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mocking => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        modal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        model => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        modeler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moderate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        moderately => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moderating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moderation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moderator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        modern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modernism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        modesty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        modicum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modifiable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        modulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        module => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        modulus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mogul => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moiety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moisture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molasses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moldy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molecular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molecule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        molestation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        molten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        momentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        momentous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        momentum => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        monad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monarch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monarchy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monastery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monastic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monetary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        money => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        monk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        monkey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monochrome => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monogamy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        monogram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monolayer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monologue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monopolist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monopoly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monotony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monsoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        monster => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monstrosity => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        monte => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        month => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monthly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        monument => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        monumental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moods => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moody => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        moon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moonlight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moored => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mooring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moorings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        moorland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mooted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moral => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        morality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        morals => { anger => 1, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        morass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moratorium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morbid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        morbidity => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        morgue => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        moribund => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        morn => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moronic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morphine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morphism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morphology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morrow => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        morsel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mortal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mortality => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mortar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mortgage => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mortgagee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        mortgagor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mortification => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mortuary => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mosaic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mosque => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mosquito => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mossy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mother => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        motherhood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        motion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motionless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        motley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motorbike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motorcycle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motte => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mottled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        motto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mould => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mountain => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mountaineer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mountainous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mourn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mournful => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mourning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moustache => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mouth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        mouthful => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mouthpiece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        movable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        move => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        movement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        movie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        moving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muck => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mucous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mucus => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muddled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muddy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muff => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muffled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muffler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mug => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        mule => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        multilateral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiplex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiplication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiplicity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiplied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiplier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multiply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        multitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mum => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mumble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mummy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mumps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        munch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mundane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        municipal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        municipality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        murder => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        murderer => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        murderous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        murky => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        murmur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muscle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muscular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        muse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        museum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mushroom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        music => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        musical => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        musician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        musing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        musk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        musket => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muslin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mustang => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mustard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        musty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mutable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mutant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mutation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mutilated => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mutilation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        mutiny => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        mutter => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mutton => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mutual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        mutually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        muzzle => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        myopia => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        myopic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        myriad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mysterious => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        mystery => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        mystic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        mystical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mysticism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        myth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mythic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mythical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mythological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        mythology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        nadir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nag => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        named => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nameless => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        namesake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nanny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nanometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        nape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        napkin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        napping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nappy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narcotic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narrative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narrator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        narrowing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nascent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nasty => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        natal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        national => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nationality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        native => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nativity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naturalist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        naturalization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naturalized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naturally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naught => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naughty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nausea => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nauseous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        nautical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        naval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        navel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        navigable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        navigate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        navigation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        navigator => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        navy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neatly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        nebula => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nebulae => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nebulous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        necessarily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        necessitate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        necessities => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        necessity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        neck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        necklace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        necrosis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nectar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        needful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        needle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        needless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        needy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nefarious => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        negation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        neglect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neglected => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        neglecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negligence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negligent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negligently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negligible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negotiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        negotiation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        negotiator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        negro => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        neigh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neighbor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        neighborhood => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neighboring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neonatal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neophyte => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neoprene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nephew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nepotism => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        nerve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        nervous => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nervousness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        nestle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        nestling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        net => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nether => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        netting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nettle => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        network => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neuralgia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        neurology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neurosis => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        neurotic => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neuter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        neutral => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        neutrality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        neutralize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        newborn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        newcomer => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        newly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        newness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        news => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        newspaper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        newsstand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nibble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        niche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nichts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nickel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nickname => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nicotine => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        niece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nigger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nigh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        night => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nightfall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nightingale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nightmare => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nihilism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nimble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ninety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ninth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nipple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nobility => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        noble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        nobleman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        nocturnal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nodding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        node => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nodular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nodule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noisy => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nomad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nomadic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nomenclature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nominal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nominate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nomination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        nominee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nonce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noncompliance => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        nondescript => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nonexistent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nonpayment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nonresident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nonsense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nonsensical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        noodle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        norm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        normal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        normalcy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        normality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        nose => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nostalgia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nostril => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        notables => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        notably => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        notation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        note => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notebook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        noteworthy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nothingness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        notice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noticeable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notification => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        notional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        notoriety => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        notwithstanding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nought => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nourish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nourishment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        nouveau => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        novelty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        novice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nowadays => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        noxious => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nozzle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nuance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nuances => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nucleus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nudge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nudity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nugget => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nuisance => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nul => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        null => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nullify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        numb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        number => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        numbering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        numbers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        numbness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        numeral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        numerator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        numerical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        numerically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        numerous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        nurse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        nursery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        nurture => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        nutmeg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nutrition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nutritious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        nutritive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nuts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        nymph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oaf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        oar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oasis => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        oath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        oatmeal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obedience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        obedient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obediently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obelisk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obese => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obesity => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        obey => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        obi => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        obituary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        object => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        objection => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        objectionable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        objective => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        obligation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obligatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oblige => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        obliged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obliging => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        obligor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oblique => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obliterate => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        obliterated => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obliteration => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oblivion => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oblivious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oblong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obnoxious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oboe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obscene => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obscenity => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obscure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obscured => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obscurity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        observance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        observant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        observation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        observatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        observe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        observer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        observing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obsession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obsolescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obstacle => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        obstetrician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        obstetrics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obstinate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obstruct => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obstruction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obstructive => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obtain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obtainable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        obtuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obverse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        obvious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ocarina => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occasion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occasional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        occasionally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occlusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occult => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occupancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occupant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        occupation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        occupied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occupier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occupy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        occupying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        occurrence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ocean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oceanic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        octagon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        octave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        octopus => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ocular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oddity => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        odds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ode => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        odious => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        odometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        odor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oestrogen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oeuvre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offend => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offended => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        offender => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        offense => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        offensive => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        offered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        offhand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        office => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        officer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        offices => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        official => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        officiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offload => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        offset => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        offshoot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        offside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oftentimes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ogre => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oils => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ointment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        older => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        olfactory => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oligarchy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        olive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omega => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omelet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omen => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ominous => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omitted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omnibus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omnipotence => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        omnipotent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omnipresent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        omniscient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        oncologist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oneness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onerous => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oneself => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ongoing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onset => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onslaught => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ontology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        onyx => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ooze => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oozing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opacity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opaque => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        open => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opener => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        openly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        openness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        opera => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        operatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        operation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        operations => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        operative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        operator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ophthalmic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ophthalmologist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opinion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opinionated => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opium => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        opponent => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opportune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        opportunism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opportunity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        oppose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opposed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opposing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opposite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opposites => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opposition => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oppress => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oppression => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oppressive => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oppressor => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        optic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        optical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        optics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        optimism => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        optimist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        option => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        optional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        optionally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        options => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        optometrist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opulence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opulent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        opus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oracle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        oral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        orator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oratory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orbit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orbiting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orbs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orc => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orchard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orchestra => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        ordained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ordeal => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        order => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orderly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ordinance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ordinary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ordination => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        ordnance => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oregano => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        organ => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        organic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        organism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        organist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        organization => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        organize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        organized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        orgasm => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        orgies => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oriental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orientation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orifice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        origin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        originality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        originate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        origination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        originator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ornament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ornamental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ornamentation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ornamented => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ornate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        orphan => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        orthodox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        orthodoxy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        orthogonal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oscillate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oscillating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oscillation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oscillatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ostensible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ostensibly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ostrich => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        otto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ottoman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ounce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oust => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        outbreak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outburst => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 0 },
        outcast => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        outcome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        outcry => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        outdo => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        outdoor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outfit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outgrow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outgrowth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outhouse => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlandish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlaw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlines => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outlying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outnumber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outpost => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outpouring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        output => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outrage => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outrageous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        outright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outrun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outset => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outsider => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outskirts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outspoken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outstanding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        outstretched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        outwards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        outweigh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ovary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ovate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ovation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        oven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overalls => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overbearing => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overburden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overcast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overcharged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overcoat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overdo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overdose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overdue => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        overestimate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        overestimated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overflow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overflowing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overgrown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overgrowth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overhanging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overhaul => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overhead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overjoyed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        overlaid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overlap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overlay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overload => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        overlying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overpaid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overpass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overpower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overpowering => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overpriced => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        override => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overrule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overseer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overshadow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oversight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overstate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overstock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overt => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overtake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overtaken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overthrow => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overture => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overturn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overwhelm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        overwhelmed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        overwhelming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        overzealous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        owe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        owing => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        owner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ownership => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oxidation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oxygen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oxymoron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        oyster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pacific => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pacify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        package => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        packer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        packet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        pad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        padding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        paddle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        paddock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paddy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        padlock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        padre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pagan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paganism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        page => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pageant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pagination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pagoda => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pain => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pained => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        painful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        painfully => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        painless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pains => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        painstaking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        painted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        painter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        painting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pajamas => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palatable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        palate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paleontology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palladium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pallet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palliative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        palm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palmer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        palpable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        palsy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        paltry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pamper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pamphlet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        panacea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        panache => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pancake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pandemic => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        panel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pang => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        panic => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        panier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        panorama => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        panoramic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pantheon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        panther => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        panties => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pantomime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pantry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pants => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        papacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        papal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paprika => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        papyrus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        par => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parabola => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parabolic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parachute => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parade => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        paradigm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paradox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paradoxical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paraffin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paragon => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        paragraph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parallax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parallel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parallelism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paralysis => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        paralyzed => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        paramount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        paranoia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parapet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paraphernalia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paraphrase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        parasite => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parasol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parcel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parcels => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parchment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pardon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pare => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        parenchyma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parentage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        parental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parenthesis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parenthetical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parietal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        paring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        parity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        park => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parlance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parliament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        parliamentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parlor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parole => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parquet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parrot => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parsimonious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parsimony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parsley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parson => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        part => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        partake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        partiality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        partially => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        participate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        participation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        particle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        particularity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        particulars => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        parting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        partisan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        partisanship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        partition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        partly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        partner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        partnership => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        parts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        party => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pas => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passageway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passenger => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        passionate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        passive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passivity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        passport => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        past => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paste => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pastel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pastime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pastor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pastry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pasture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pasty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patchwork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patella => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        paternal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paternity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        path => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pathetic => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pathology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pathos => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pathway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patience => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        patient => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        patio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patriarch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patriarchal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        patrimony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patriot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patriotic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patriotism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patrol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        patron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        patronage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        patronize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patronizing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        patter => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pattern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paucity => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pauper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pause => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pavement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        pavilion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        paw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pawn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        pax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pay => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        payback => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        payer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        payment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peace => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        peaceable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        peaceful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        peacock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        peak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peaked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pearl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peasant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pebble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        peculiar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peculiarities => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peculiarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        peculiarly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pecuniary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pedal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pedantic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pedestal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pedestrian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pediatrics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pedigree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pedometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peerless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        peg => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pegs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pelagic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pellet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penal => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        penalty => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        penance => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        penchant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pencil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pendant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pendency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pendent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pendulum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penetrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penetrating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penetration => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peninsula => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penitentiary => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pennant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penniless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pension => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pensioner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pensive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pentagon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penthouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        penultimate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        people => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peopled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pepper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perceive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        percentage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perceptible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        perception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perceptive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perchance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        percolation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        percussion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perdition => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        peremptory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perennial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        perfect => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        perfection => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        perforated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perforation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perforce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        performance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        performer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        perfume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perfumed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peri => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        peridot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peril => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perilous => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perimeter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        period => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        periodic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        periodical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        periodically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        periodicity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        periphery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perish => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perishable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perishing => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perjury => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        perk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        permanence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permeable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permeate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permeation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permissible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        permissive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permitted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permitting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        permutation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pernicious => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perpendicular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perpetrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perpetrator => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perpetual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perpetually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perpetuate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perpetuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perpetuity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        perplexed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perplexing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perplexity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        persecute => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persecution => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        perseverance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persevere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persistence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        persistent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        persisting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        person => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        personable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        personage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        personal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        personification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        personnel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perspective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perspiration => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persuade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        persuasion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        persuasive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pertinent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        perturbation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pertussis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perusal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        peruse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pervading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perverse => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perversion => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pervert => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        perverted => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pessimism => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pessimist => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pest => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pestilence => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        petition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        petitioner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        petrol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        petroleum => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        petting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        petty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pewter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phalanx => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        phantom => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pharmaceutical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pharmacist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pharmacology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pharmacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phenomenon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        philanthropic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        philanthropist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        philanthropy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        philosopher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        philosophic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        philosophical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        philosophy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phlegm => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phoenix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        phone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phonetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        phonetics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phonics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phonograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phonology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phony => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phosphor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phosphorus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        photo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        photogenic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        photograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        photographer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        photography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        photometry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phrase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phraseology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        phylogeny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        physical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        physician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        physicist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        physics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        physiology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        physique => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pianist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piano => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piazza => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piccolo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        picked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        picket => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        picketing => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pickle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pickup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        picnic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        pictorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        picture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        picturesque => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piecemeal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pierce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pig => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pigeon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pigment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piles => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pilgrim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pilgrimage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pillage => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pillar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pillow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pillowcase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pilot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pimp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pimple => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pinch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pinching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pineapple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pinhole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pinion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pinnacle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pioneer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pious => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        pip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pipe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piped => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pipeline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pipette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pique => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piracy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pirate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piscina => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pistol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        piston => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pitch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pitcher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pitfall => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        pith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pithy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pitted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pivot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        placard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        place => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        placebo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        placid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        placket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plagiarism => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plague => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        plaid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plaintiff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plaintive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        plan => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planetarium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planets => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planning => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        plant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plantation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        planting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plasma => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plaster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plastic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plasticity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plateau => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        platform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        platoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        platter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plausibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        play => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        playa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        player => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        playful => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        playground => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        playhouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        playmate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        playwright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plaza => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plea => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pleasant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        pleased => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pleasurable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pleat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pleated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pledge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        pledged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plenary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        plentiful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        plenty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plenum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plethora => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plexus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pliable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pliers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plight => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        plinth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plodding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ploughed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plowed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plowing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pluck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        plumage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plumb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        plume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plummet => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plump => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plumper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plunder => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        plunge => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plurality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        plush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        plutonium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pneumonia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poaching => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pocket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pocketbook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poetical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poetics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poetry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poignant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        point => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pointedly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pointer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pointless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        poise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poison => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        poisoned => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        poisoning => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poisonous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        poke => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        pole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polemic => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        police => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        policeman => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        policy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        polio => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        polish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        polished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        polite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        politeness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        politic => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        politician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        politics => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        pollute => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pollution => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polygamy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polygon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polygonal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polymer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        polymorphism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pomp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pompous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poncho => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pond => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ponder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ponderous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pontiff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        pontificate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pontoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poodle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pool => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        poop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poorly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        pope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        poppy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        popular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        popularity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        popularized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        population => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        populous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porcelain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porcupine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pork => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porn => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porno => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pornographic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pornography => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porosity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porridge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        port => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        portage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        porter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portfolio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portico => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portrait => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portraiture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        portray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        posited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        position => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        posse => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        possess => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        possessed => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        possessing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        possession => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        possessor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        possibility => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        possibly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        post => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        postal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        posterior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        posterity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        posthumous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        postpone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        postponed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        postponement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        postscript => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        postulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        posture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        potable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        potency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        potent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        potential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        potion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        potluck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        potpourri => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        potter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pottery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pouch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poultry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pound => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        poverty => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pow => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        powder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        powdered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        powdery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        powerful => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        powerfully => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        powerless => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        practicable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        practical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        practically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        practice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        practiced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        practise => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        practitioner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prairie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        praise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        praised => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        praiseworthy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        prank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        praxis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pray => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        prayer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preacher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preaching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preamble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precarious => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        precaution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        precautionary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precede => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        precedence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        precedent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preceding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precept => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preceptor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precinct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precincts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precious => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        precipice => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precipitate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precipitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precipitous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        precisely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        preclude => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precocious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        precursor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predatory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predecessor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predicament => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predicate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predict => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predicting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prediction => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predictive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predictor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predilection => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        predispose => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predisposed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predisposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predominance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        predominant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        predominate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preeminent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        preemption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preface => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prefect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prefer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        preference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preferential => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prefix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pregnancy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prehistoric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prejudice => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prejudiced => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prejudicial => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preliminary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prelude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        premature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        prematurely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        premeditated => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        premier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        premise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        premises => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        premium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preoccupation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preoccupied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preparation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preparatory => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prepare => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prepared => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        preparedness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preparer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preparing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preponderance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        prerequisite => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prerogative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prescient => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prescribed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prescription => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prescriptive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        presence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        present => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        presentable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        presentation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        presentment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        preservation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preservative => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        preserve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        preserved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preserving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        presidency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        president => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        press => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pressing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pressure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prestige => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        presto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        presumption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        presumptive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        presumptuous => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        presuppose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretending => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretensions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretext => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pretty => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        prevail => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prevailing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prevalence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prevalent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        prevent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        preventative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prevention => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        preventive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        previous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        previously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prey => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        price => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        priceless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prick => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        prickly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pride => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        priest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        priesthood => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        priestly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        primacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        primary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        primate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        primates => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        primed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        primer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        primeval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        priming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        primitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        primordial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prince => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        princely => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        princess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        principal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        principally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        principle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        print => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        printer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        printing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        priority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        priory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prismatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prison => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        prisoner => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pristine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        privacy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        private => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        privately => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        privilege => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        privileged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        privy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        probability => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        probable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        probation => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        probationary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        probative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        probe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        probity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        problem => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        procedure => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        proceed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proceeding => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proceeds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        process => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        procession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 0 },
        proclaim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proclamation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        procrastinate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        procrastination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        procreation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proctor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        procure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        procurement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prodigal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prodigious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prodigy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        produce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        produced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        producer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        producing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        product => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        production => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        productive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        productivity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        profane => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        profanity => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        profess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        profession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        professional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        professor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        professorship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        proficiency => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        proficient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        profile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        profit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        profuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        profusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        progenitor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        progeny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prognosis => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prognostic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        program => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        programme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        programmer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        progress => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        progression => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        progressive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prohibit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prohibited => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prohibition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prohibitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        project => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        projectile => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        projectiles => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        projecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        projection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        projector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proletarian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proletariat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prolific => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prologue => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prolong => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prolongation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prolonged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promenade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prominence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prominently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        promiscuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        promising => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        promissory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promontory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promoter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promotion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prompt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prompting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promulgate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        promulgation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pronounce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pronounced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pronouncement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pronunciation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        prop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        propaganda => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propagate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propagation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propelled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propeller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propelling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propensity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        property => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prophecy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prophesy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prophet => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        prophetic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prophylactic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        prophylaxis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proportion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proportional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proportionate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proportions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proposal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        proprietary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proprietor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proprietorship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propriety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        propulsion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prosecute => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        prosecution => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prosecutor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prospect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prospective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prospectively => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prospectus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prosper => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prosperity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prosperous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prostitute => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prostitution => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        prostrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protagonist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        protected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        protecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        protection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        protector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        protein => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protestant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protocol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prototype => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protozoa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protracted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protrude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        protrusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proud => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        prove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        proven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        proverb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proverbial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        provide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        provided => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        providence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        providing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        province => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provincial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provisionally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provisions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proviso => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        provocation => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provocative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provoking => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        provost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prowess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        prowl => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        proximal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proximate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proximity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        proxy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        prudence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        prudent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        prune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pry => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        prying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psalm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pseudo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pseudonym => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psyche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psychical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psychics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psychological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psychologist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psychology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        psychosis => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        pub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puberty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pubescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        public => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        publication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        publicist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        publicity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        publicly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        publish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        published => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        publisher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pudding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puffy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puke => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pulley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pullover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pulmonary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pulp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pulpit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        pulsation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pulse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puma => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        pump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        punch => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        punctual => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        punctuality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        punctually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        punctuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puncture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pundit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pungent => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        punish => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        punished => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        punishing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        punishment => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        punitive => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        punk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        punt => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pupil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puppet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puppy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        purchase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purchaser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purchasing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        purgatory => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purge => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        purify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        purist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        purity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        purple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purport => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purpose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purposely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purr => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        purse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pursuance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pursuing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pursuit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purveyor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        purview => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pus => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        push => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pushing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pussy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pussycat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        put => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        putative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        puts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        putty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puzzled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        puzzling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pygmy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pyramid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pyramidal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        pyrotechnics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quack => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quadrangle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quadrant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quadratic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quadrature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quadruple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quadrupole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quagmire => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quail => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quaint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        quake => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        qualified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        qualify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        qualifying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        qualities => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quandary => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quantify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quantitative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quantitatively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quantity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quantum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quarantine => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quarrel => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quarry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quarter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quartered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quarters => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quartet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quartile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quarto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quartz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quash => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quasi => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quaternary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        queen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        queer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quench => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        query => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quest => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        question => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        questionable => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        questioning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        queue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quicken => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quickly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quickness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        quicksilver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        quid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quiescent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        quiet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        quietly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quilt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quinine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        quit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quits => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quiver => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quivering => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quiz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quorum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quota => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quotation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        quote => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        quotient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rabbit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rabble => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rabid => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rabies => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        race => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        racehorse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        racer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        racket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        racking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        racy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        radiance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        radiant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        radiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        radiation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        radioactive => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radioactivity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radiograph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radiography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radiology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radius => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        radon => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raffle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        raft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rage => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ragged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raging => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rags => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raid => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        rail => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        railing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        railroad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        railway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raiment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raincoat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rainfall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rainy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        raise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raised => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raising => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ram => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ramble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rambling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ramp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rampage => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ranch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rancid => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        randomly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        randomness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        randy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ranger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        rank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ransom => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rape => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rapid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        rapidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rapids => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rapping => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rapt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        raptors => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rapture => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rarely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        rascal => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rash => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rat => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ratchet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ratification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ratify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        rating => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ratio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rational => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        rationale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rationalism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rationality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rattan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rattle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rattlesnake => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raucous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rave => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        raven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ravenous => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ravine => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        raving => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        rawhide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        razor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        react => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reactionary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        read => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reader => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        readership => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        readily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        readiness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        readjustment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ready => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reaffirm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reagent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        real => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        realism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        realistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        realm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        realty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ream => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reappear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        rear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rearrange => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rearrangement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reason => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reasonableness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reasoning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reasons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reassemble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reassurance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reassure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reassured => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reassuring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rebate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rebel => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rebellion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reborn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rebound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rebuild => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rebuke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rebut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recalcitrant => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recede => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        receding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        receipt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        receipts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        received => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        receiver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        receiving => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        recent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        receptacle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reception => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recesses => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recession => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        recherche => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recidivism => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        recipe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recipient => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reciprocal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reciprocate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reciprocity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recital => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reckless => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recklessness => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        reckoning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reclamation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        recluse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recognition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recognizable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recognized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recoil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recollect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recollection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recombinant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recombination => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recommend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        recommendation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recompense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reconcile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reconciliation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reconnaissance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reconsider => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reconsideration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reconstitution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reconstruct => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reconstruction => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        record => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recorder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recording => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recoup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recourse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recoverable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recovery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recreation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recreational => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        recruit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recruiting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recruits => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        rectangle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rectangular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rectification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rectify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rectory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recumbent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recuperation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recurrence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recurrent => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recurring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recursion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recursive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        recursively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        red => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reddish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        redemption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        redness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        redress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reduced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        redundancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        redundant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reef => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reefs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reestablish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        referee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        reference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        referendum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        refinement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        refinery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reflect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reflecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reflection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reflective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reflector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reflex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        reflux => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reformation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reformer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        refraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refractor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refractory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refrain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refraining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refreshing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        refrigerate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refrigeration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refrigerator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refuge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refugee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        refund => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refurbish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        refusal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refuse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refused => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        refusing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refutation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        refute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        regalia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regatta => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regenerate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regeneration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        regime => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regimen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regiment => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        region => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regionalism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        register => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        registrar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        registration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        registry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        regress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regression => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regressive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        regret => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        regrettable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        regretted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        regretting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        regular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regularity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        regulars => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        regulated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regulatory => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        regurgitation => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rehabilitate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rehabilitation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rehearsal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reimburse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reimbursement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        rein => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reindeer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reinforce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reinforcement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reinforcements => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        reins => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reinstall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reinstate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reinstatement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reinvest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reinvestment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reiterate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reject => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rejected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rejection => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rejects => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rejoice => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        rejoicing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        rejoin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rejuvenate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rejuvenated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rekindle => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        relapse => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        relate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        related => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        relation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relationship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        relativity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relaxant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relaxation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        relaxed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        release => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        released => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relegation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relevancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relevant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reliability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reliable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reliance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        relic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        relief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        relieving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        religion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        religious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relinquish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        relish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reluctance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reluctant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remainder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remaining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remains => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        remake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        remand => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remarkable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        remarkably => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        remedial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remedy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        remember => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remembered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remembering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remembrance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reminder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remiss => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        remission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        remit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remittance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remnant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remodel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        remorse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        remote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remoteness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        removal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        remove => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        remuneration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renaissance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rencontre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        render => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rendering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rendezvous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rendition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renegade => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renewal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        renounce => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renovate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        renovated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renovation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        renown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        renowned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        renunciation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reorganization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reorganize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        repair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reparation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        repay => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        repayment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repeal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repeat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repeated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repeatedly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repeater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repellant => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repellent => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repelling => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        repentance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repertoire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repertory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repetition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        replace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        replacement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        replenish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        replete => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        replication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        report => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reported => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reporter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        repose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repository => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        representation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        representative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        represented => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        representing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        repressed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repression => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reprieve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reprimand => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reprint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reprisal => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        reprise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reproach => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        reproduce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reproduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reproductive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reptile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        republic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        republican => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repudiation => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repulsion => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repurchase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reputable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reputation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        repute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        request => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        requiem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        required => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        requirement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        requisite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        requisition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rescind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rescission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rescue => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        research => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resection => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resemblance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resemble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resembling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resent => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resentful => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resentment => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        reservation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reserve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reserved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reserves => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reservoir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        residence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        residences => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        residual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        residue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resign => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        resignation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        resigned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        resilience => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resilient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        resin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resistance => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resistant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resisting => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        resistive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        resolute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resolutely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        resolution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resolve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resolved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resonance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resonant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resonate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resonator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resounding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resources => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        respect => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        respectability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        respectable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        respected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        respectful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        respecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        respective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        respects => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        respiration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        respirator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        respite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        resplendent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        respond => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        respondent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        response => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        responsibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        responsible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        responsive => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        rest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        restaurant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        restitution => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        restlessness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restoration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restorative => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        restored => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restoring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        restrain => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restrained => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restraint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        restrict => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        restricted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        restriction => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        restrictive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        result => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resultant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resumption => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        resurrection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        resuscitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retailer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        retaining => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retaliate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retaliation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retaliatory => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retard => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        retardation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retention => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        retentive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reticent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retina => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retired => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retirement => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        retiring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retract => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrenchment => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retribution => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        retrieval => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrieve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retriever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retroactive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrograde => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrospect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrospective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        retrospectively => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        return => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reunion => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reveal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        revelation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revels => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        revenge => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        revenue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reverberation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revere => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reverence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reverend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        reverent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reverie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        reversal => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        reverse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reversion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reverting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        review => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reviewer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        revision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revisit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revival => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        revive => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        revocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revoke => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        revolt => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        revolting => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revolution => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 0 },
        revolutionary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        revolutionize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revolve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        revolver => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        revulsion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        reward => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        rhetoric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rhetorical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rheumatism => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rhyme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rhyming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rhythm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rhythmical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        rib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ribbed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ribbon => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riches => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        richness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rickety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riddance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        riddled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ride => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rider => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ridge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ridicule => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ridiculous => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rife => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rifle => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rifles => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rigging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        righteous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rightful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rightly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rigid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rigidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rigor => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rigorous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ringer => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ringing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rinse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riot => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riotous => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        riparian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ripe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ripen => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ripening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ripple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rising => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        risk => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        risky => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ritual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ritualistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rival => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rivalry => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        river => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riverbank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rivet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riveted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        riveting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        road => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roads => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roadster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        roadway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rob => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        robber => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        robbery => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        robe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        robot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        robotics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        robust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        roc => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rocket => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rocks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rod => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        roe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rogue => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        role => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rollers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rollicking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rolling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        romance => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        romantic => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        romanticism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        romp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        roof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rook => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        room => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rooster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        root => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rooted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        rope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rosary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rosemary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rosette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rosy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rot => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rota => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        rotary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rotate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rotation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rotor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rotting => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rouge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roughly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roughness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roulette => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        round => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roundabout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rounded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roundup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rouser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rousing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        route => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        routine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        rover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        roving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        row => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rowdy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        royal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        royalty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        rub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rubber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rubbers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rubbing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rubbish => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rubble => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rubric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ruby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rudder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ruddy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rudimentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rudiments => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ruff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ruffle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rugged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ruin => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ruined => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ruinous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ruins => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rule => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        ruler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ruling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rumble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rummage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rumor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        rumored => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        runaway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        runes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rung => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        runner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        running => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        runway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rupture => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        rural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ruse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rustic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rustle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rusty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ruth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ruthless => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        rye => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saber => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sabotage => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        sac => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sacrament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sacred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sacrifices => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        saddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sadly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sadness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        safe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        safeguard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        safekeeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        safety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saffron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sag => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saga => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sailing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sailor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saint => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        saintly => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        salad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salamander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salesman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        saline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saliva => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        salon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saloon => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salutary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        salutation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        salvage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        salvation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        salve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        samba => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sameness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        samurai => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sanctification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sanctified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sanctify => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        sanction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sanctioned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sanctity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sanctuary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sandal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sands => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sandy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sanguine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sanitary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sanity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sans => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sapphire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sappy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sarcasm => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sarcoma => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sardonic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satanic => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satchel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satellite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        satire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satirical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satisfaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        satisfactorily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        satisfied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        saturate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saturated => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saturation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sauce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saucepan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saucer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saucy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sauerkraut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sauna => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        savage => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        savagery => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        savanna => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        save => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        saving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        savings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        savor => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        savory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        savvy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sawdust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        saxophone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scabbard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scaffold => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scaffolding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scales => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scallop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scalp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scalpel => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scaly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scandal => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scandalous => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scanty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scapegoat => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scar => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scarab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scarce => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scarcely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scarcity => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scare => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        scarecrow => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        scarf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scarlet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scatter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scattered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scattering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scavenger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scenery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scenic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sceptical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        scepticism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        schematic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scheme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        schism => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        schizophrenia => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scholar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        scholarly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scholarship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        school => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        schoolboy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        schooling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        schoolmaster => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        schooner => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sciatica => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        science => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scientific => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        scientist => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        scintilla => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        scintillation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scintillator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scissors => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scoff => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scold => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scolding => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scoop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scorching => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        score => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        scores => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scorn => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scorpion => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        scotch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scoundrel => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        scour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scourge => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrabble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scramble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrambling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrapie => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        scraping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scratch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scream => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        screaming => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        screech => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        screen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        screwdriver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        screwed => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scribble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scribe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        scrimmage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        scrip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        script => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        scriptural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scripture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        scroll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrub => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrumptious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        scrupulous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrutinize => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scrutiny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sculptor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sculpture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sculptured => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        scum => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        seaboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        seals => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        seam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seaman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seamless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seamstress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seaport => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        search => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        searching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seared => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seaside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        season => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seasoned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        seasoning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secluded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        seclusion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        secondary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secondhand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secrecy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 1 },
        secret => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        secretariat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        secretary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secrete => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secretion => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secretive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secretly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sect => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sectarian => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sectional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secular => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        secularism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        securities => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        security => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sediment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedimentary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sedition => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        seduce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seducing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seductive => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seedling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seek => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seeker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seemingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seething => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        segment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        segregate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        segregated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        segregation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seize => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seizure => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seldom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        select => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        selection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        selfish => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        selfishness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        semaphore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        semblance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        semen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        semicolon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seminal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seminar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seminary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        semiotics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        senate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        senator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        send => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        senescence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        senile => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        senior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seniority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sensation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sensational => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        senseless => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        senses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sensibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sensibly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sensitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sensory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sensual => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        sensuality => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sensuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sentence => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sentient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sentiment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sentimental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sentimentality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sentinel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sentry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        separable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        separate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        separately => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        separation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        separatist => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sepia => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sepsis => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sept => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        septic => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        septum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sequel => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sequence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sequent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sequestered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sequestration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        serene => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        serenity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sergeant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        serial => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        series => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        serif => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seriousness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sermon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        serpent => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        serpentine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        serrated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        serum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        servant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        serve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        service => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        serviceable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        servile => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        servitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sess => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        session => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sessions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        set => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        setback => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sett => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        setter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        settle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        settled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        settler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        settlor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        seventh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        seventy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        severable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        severally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        severance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        severely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        severity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sewage => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sewer => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sewerage => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sex => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sexuality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sexy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shabby => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shack => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shackle => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shades => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shadow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shadowy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shady => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaft => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaggy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaking => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaky => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sham => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shambles => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shame => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shameful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shameless => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shanghai => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shank => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shanty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        shapely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        share => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        shareholder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sharpen => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sharpened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sharpener => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sharpness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shatter => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        shattered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shaving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shawl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheaf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shears => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheathing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sheet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shelf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shell => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        shellfish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shelter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        shelved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shepherd => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sheriff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sherry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shield => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shifting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shilling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shimmer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        shingle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shining => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        shiny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ship => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shipment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shipping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shipwreck => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shirt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shit => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shiver => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shivering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shoals => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shock => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        shockingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        shoddy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shoe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shoemaker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shoot => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shooter => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shooting => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shopkeeper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        shoplifting => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shopping => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        shore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shorn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        short => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shortage => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shortcoming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shorten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shortening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shorthand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shortly => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shortness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shorts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shot => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        shotgun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shoulder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        shout => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        shove => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shovel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shoveling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        show => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        shower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        showing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        showy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrapnel => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrewd => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        shriek => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        shrill => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        shrimp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrink => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shrinking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shroud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shrub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrubbery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shrunk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shudder => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shuffle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shuffling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shun => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        shunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shutter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        shuttle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sib => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sick => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sickening => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sickle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sickly => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sickness => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        side => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sideboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sidestep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sideways => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        siege => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        siesta => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sieve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sifting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sigh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        signal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        signature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        significance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        significant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        signification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        signify => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        signpost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silhouette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        silken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silliness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        silvery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        similar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        similarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simmer => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simmering => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simples => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simplify => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        simply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simulated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simulating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simultaneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        simultaneously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sin => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sincere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sincerity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sinful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        singer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        single => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        singly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        singular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        singularity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        singularly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        sinister => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sinner => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sinning => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sinus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        siphon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        siren => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sissy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sister => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sisterhood => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        site => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sitting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        situate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        situated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        situation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sixth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sixty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        size => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sizzle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skein => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skeleton => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skeptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skeptical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skepticism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sketch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sketchy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skewed => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skewer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ski => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skid => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        skiff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skilled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        skillet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skillful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        skim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skinny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skipper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skirmish => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skirt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skirting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skirts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skull => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        skunk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        skyscraper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slam => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        slander => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slanderous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slang => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slap => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        slash => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slashes => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        slates => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slaughter => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        slaughterhouse => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        slaughtering => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        slave => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        slavery => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        slay => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slayer => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        sledge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleek => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sleep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleeper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleeplessness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleepy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleeve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleeveless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleigh => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sleight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sleuth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sliding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slightly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        slime => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slimy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        slipper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slippers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sliver => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slogan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sloop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slop => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sloppy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sloth => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slouch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slowly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slowness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sludge => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slug => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sluggish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sluice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slum => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slumber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        slump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        slur => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        slush => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        slut => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sly => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smack => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        small => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smaller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smallest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smash => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smashed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smattering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smell => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smelling => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smelt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        smiling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        smirk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smite => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        smith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        smitten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        smoker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smokey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smoking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smoky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smoldering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smoothly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smoothness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        smother => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smudge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smuggle => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smuggler => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smuggling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        smut => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snacks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        snags => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snake => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snapshot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snare => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snarl => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snarling => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sneak => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        sneakers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sneaking => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sneer => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sneeze => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        sneezing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snicker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        snide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sniff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snipe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snippet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snob => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snoopy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snooze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        snout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snowball => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snowflake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snowy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        snuff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soaking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soapy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soaring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sob => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sobriety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        soc => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soccer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sociable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        social => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        socialism => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        socialist => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        society => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        socket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sofa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        softening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        softness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soggy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soil => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soiled => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sojourn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        solar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soldering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soldier => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        sole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solicit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solicitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solicitor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        solidarity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        solidification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solidified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solidify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        solitaire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solitary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solitude => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solubility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soluble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        solve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        solvency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        solvent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        somatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        somber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        son => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sonar => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sonata => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        song => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sonnet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        sonorous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        soot => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soothe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        soothing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sophomore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soprano => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sorcerer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sorcery => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        sordid => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sore => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sorely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        soreness => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sorghum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sorority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sorrow => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sorrowful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sorter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sortie => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sorting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sou => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soulless => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        soulmate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sounding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        soundness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        soup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sour => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        source => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        souvenir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sovereign => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sovereignty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spa => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        space => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spacious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        span => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spaniel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        spank => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        spanking => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sparingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sparkle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        sparring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sparse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spasm => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spat => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spatula => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spawn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speaker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speaking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spear => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        special => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        specialist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        speciality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specialize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        specially => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        species => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specific => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specimen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speck => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speckled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spectacle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spectacles => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spectacular => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        spectator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        specter => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        spectral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spectrometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spectrophotometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spectroscopy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spectrum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speculate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speculation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        speculative => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speculum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speech => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        speechless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speedily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speedometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speedway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        speedy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spellbound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spelling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spencer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sperm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spew => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sphere => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spherical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sphinx => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spicy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spider => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spigot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spike => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spiked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spiky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spinal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spindle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spine => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spinning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spinster => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        spiny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spiral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spirit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spirits => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        spiritual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spirituality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spit => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spite => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spiteful => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        splash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        spleen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        splendid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        splendor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        splice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        splint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        splinter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        split => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        splitting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        splurge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoil => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoiler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        spoiling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spokesman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sponge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spongy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sponsor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sponsorship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spook => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spoonful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sporadic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sport => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sporting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sports => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sportsman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spotless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        spotted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spotty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spousal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        spout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sprain => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sprawl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spree => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sprinkling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sprite => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sprout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spruce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        spur => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spurious => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spurred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spurt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        spy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squadron => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squall => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        squamous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        square => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squatter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squeak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squeal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squeamish => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squeeze => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squeezing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squelch => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squirm => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squirrel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        squirt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stab => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        stability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        staccato => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        staff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stagger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        staggering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stagnant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stagnation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        staid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stain => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stainless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stair => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        staircase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stairway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stalemate => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stalk => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stall => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stallion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stalls => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stalwart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stamina => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        stamp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        standard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        standardize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        standing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        standoff => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        standpoint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        standstill => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stanza => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        staple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        star => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        starboard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        starch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        staring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stark => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        starlight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        starry => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stars => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        start => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        startle => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        startling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        starvation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        starved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        starving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        state => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stately => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        statement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        stateroom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        statesman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        static => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        statics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        station => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stationary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stationery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        statistical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        statistician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        statuary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        statue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        statuette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        status => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        statute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        statutory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        staunch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stay => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stayed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stays => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steadfast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        steady => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 1 },
        steal => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stealing => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stealth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        stealthily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        stealthy => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        steamboat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steamer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steamroller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steamship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steamy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steeple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stellar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stench => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stencil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        step => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steppe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stereoscopic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stereotype => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stereotyped => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sterile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sterility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sterling => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        stern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stethoscope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        steward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        stewardship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sticking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sticky => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stiff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stiffen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stiffness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stifle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stifled => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stifling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stigma => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stiletto => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stillborn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stillness => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        stilts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stimulant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stimulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stimulus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sting => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stinging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stingy => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stink => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stinking => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stint => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stipulate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stipulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stirring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stitch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stockbroker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stocking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stocks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stolen => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stomach => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stone => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stoned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stoneware => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stool => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stools => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stoop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stoppage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stopper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stopping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stopwatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        storage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        store => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        storehouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        storing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        storm => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        storming => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stormy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        story => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stove => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        straddle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        straight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        straighten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        straightforward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        straightway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strained => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strait => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        straits => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stranded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stranger => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strangle => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        strap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strapping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strata => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strategic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        strategist => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        strategy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stratification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stratum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stratus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        straw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        streak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        streaked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stream => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        streamer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        streaming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        street => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strength => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        strengthen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        strengthening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        strenuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stretch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stretcher => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stricken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stride => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strife => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strike => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        striking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        strikingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        string => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stringy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stripe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stripped => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        strive => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strobe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stroke => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        stroll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stronghold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        strongly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        structural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        structure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        struggle => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        strut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stubble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stubbornness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stubby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stucco => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stuck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        studded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        student => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        studied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        studio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        study => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        stuff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stuffing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stuffy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stumble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stunned => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        stunt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stunted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stupendous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stupid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stupidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stupor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sturdy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sturgeon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stutter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sty => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        style => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        stylish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subatomic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subcommittee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subconscious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subcutaneous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subdivide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subdivision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subduction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subdue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subdued => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subito => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        subject => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subjected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        subjection => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subjective => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subjugation => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sublimation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        subliminal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        submarine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        submerged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        submersible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        submission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        submit => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subordinate => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subordination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subplot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subpoena => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subscribe => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subscription => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsequence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsequent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsequently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subset => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subside => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsidence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        subsidiary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsidize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsidy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsistence => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subsoil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        substance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        substantially => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        substantiate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        substantive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        substitute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        substituted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        substitution => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        substructure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subterranean => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subtle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subtlety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subtract => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subtraction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subtype => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suburb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suburban => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suburbs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subversion => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        subversive => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        subvert => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        subway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        succeed => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        succeeding => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        success => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        successful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        succession => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        successive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        successor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        succinct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        succulent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        succumb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sucker => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sucking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suckling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sudden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        suddenly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        sue => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suffer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sufferer => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suffering => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suffice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sufficiency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sufficient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sufficiently => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suffix => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suffocating => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suffocation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sugar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        suggest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        suggestion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suggestive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suicidal => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suicide => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        suite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suitor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sullen => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sulphur => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sultan => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sultry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summarily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summarize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        summons => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sumo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sump => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sumptuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sun => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        sunbeam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sundial => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        sundown => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sundry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sunglass => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sunglasses => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sunk => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sunless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sunlight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sunny => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        sunrise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sunset => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sunshine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        superannuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        superficial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superfluous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superhuman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        superimposed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superintendent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        superiority => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        superlative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        supermarket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supernatant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supernatural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supersede => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        superstar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        superstition => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        superstitious => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supervise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supervision => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supervisor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supplant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supplement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supplemental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supplementary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supplication => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        supplies => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        supply => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        supported => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        supporter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        supporters => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supporting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        suppose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supposing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suppress => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        suppression => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        supremacy => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        supreme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        supremely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        surcharge => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        surf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surface => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        surgeon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surgery => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        surly => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surmise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        surname => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surpassing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        surplus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surprise => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        surprised => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        surprising => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        surprisingly => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        surrender => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        surrendering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        surrogate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        surround => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        surrounding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surroundings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surveillance => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        survey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        surveying => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        surveyor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        survival => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        survive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        surviving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        susceptibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        susceptible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspect => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspenders => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspense => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        suspension => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspicion => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspicions => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suspicious => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sustained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sustenance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        suture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swagger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swallow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swamp => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swamped => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swampy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swarm => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swarming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swastika => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        swearing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweat => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweating => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweet => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        sweeten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweetened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweetener => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweetheart => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        sweetie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sweetness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        sweets => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        swell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swelling => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sweltering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swerve => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        swift => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        swiftly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swig => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swim => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        swimming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swine => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swinging => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        switch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swivel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swollen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        swoop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        sword => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        syllable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        syllabus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symbol => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symbolic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        symbolically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symbolism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symbolize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symmetric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symmetrical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        symmetry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        sympathetic => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        sympathize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        sympathy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 0 },
        symphony => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        symptom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        symptomatic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synagogue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synchronize => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        synchronous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        syncope => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        syndicate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synergistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        synergy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        synonym => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synonymous => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        synopsis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synoptic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        syntax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synthesis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        synthetic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        syringe => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        syrup => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        system => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        systematic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        systematically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tabby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tabernacle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        table => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tableau => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tablespoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tablet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tableware => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taboo => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tabular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tabulate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tabulation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tachometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tacit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tackle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        tackling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tacky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tactics => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tactile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taffeta => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taffy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tailed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tailings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tailor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tailoring => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        taker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        talent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        talented => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        talisman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        talk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        talkative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        talker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tallies => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tallow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        talons => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tambourine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tandem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tang => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tangent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tangle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tangled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tanned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tantalizing => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        tantamount => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tapering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tapestry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tardiness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tardy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        target => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tariff => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tarnish => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tarry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tartan => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tartar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        task => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tassel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taste => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tasteful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tasteless => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tasting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tasty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tattoo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taught => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        taunt => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        taut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tavern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tawny => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        taxicab => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        taxonomy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teach => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        teacher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        teaching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        team => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tearful => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tease => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        teaser => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teasing => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        technical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        technicality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        technician => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        technology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tedious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tedium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teeming => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teens => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        teeth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teflon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telegram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telegraph => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telephone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telescope => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telescopic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        television => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        teller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        telltale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tempera => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temperament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temperance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        temperate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        temperature => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tempered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tempest => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        temple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temporal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temporarily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temporary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tempt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        temptation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tempting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tenacious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tenacity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tenancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tenant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tendency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tender => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        tenderness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tendon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenement => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenets => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenfold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tennis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tense => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tensile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tension => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tentacle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tentative => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenths => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tenure => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tepid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        term => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terminal => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        terminate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        termination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        terminus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        termite => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terms => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tern => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ternary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terrace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terrestrial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terrible => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        terribly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        terrier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terrific => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        territorial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        territory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terror => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        terrorism => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        terrorist => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        terrorize => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        terse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tertiary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        test => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        testament => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        testify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        testimonial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        testimony => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tetanus => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tether => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tethered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tetrahedral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        text => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        textbook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        textile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        textural => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        texture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thankful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        thanksgiving => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        thatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thaw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theater => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theatrical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theft => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        theism => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theocracy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theocratic => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        theologian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        theology => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        theorem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        theoretical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        theory => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        therapeutic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        therapeutics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        thereabouts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thereof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        therewith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thermal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thermocouple => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thermodynamics => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thermometer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        thermostat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thesaurus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thesis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thicken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thickening => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thicket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thickness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thief => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        thimble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        things => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thinker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        thinking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thirds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thirst => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        thirsty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thirteen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thirteenth => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thistle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thither => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thorn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thorny => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thoroughbred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        thoroughfare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thought => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thoughtful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        thoughtfulness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        thoughtless => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thoughts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thousand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thrash => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        thread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        threat => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        threaten => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        threatening => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        threefold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thresh => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        threshold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thrice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thrift => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        thrifty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thrill => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        thrilling => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        thriving => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        throat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        throb => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        throbbing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        throne => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        throng => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        throttle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        throw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thrush => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thrust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thud => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thug => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thumb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thump => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thumping => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thunder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thunderbolt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thundering => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thunderstorm => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        thwart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        thyme => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiara => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ticker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ticket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tickle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        ticklish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tidal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tidbit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tidings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tier => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiff => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tighten => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tightness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tights => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tilde => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        till => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tillage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiller => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tilt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tilting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        timber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        timberland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        timbre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        time => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        timeliness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        timely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        timepiece => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        timid => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        timidity => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tincture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tinge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tingle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tingling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tinker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tinkering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tinnitus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tinsel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tint => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiny => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tipsy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tirade => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tired => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiredness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tiresome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tissue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        titanic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tithe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        title => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        titled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        titty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        titular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toad => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tobacco => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toby => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        today => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toga => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toilet => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toils => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        token => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tolerance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tolerant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tolerate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        toleration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        toll => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tomahawk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tomb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tomcat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tomorrow => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ton => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tongs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tongue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tonic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tonnage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tonsils => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tooling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tooth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toothache => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toothed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toothless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        top => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        topaz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        topic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        topical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        topographic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        topographical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        topography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        topple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        tor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torment => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        torn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tornado => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torpedo => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torrent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torrid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torsion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torso => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tort => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tortious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tortoise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tortuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        torture => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        toss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        total => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        totality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        totally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tote => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        totem => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        touch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        touched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        touching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        touchy => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        toughness => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        tour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tourist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tourmaline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tournament => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tourniquet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        towel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        towering => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        town => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        townhouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toxic => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toxicology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toxin => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        toy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traces => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trachea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tracing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        track => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tract => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tractable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tractor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        trader => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tradesman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trading => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tradition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traditional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        traffic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tragedy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tragic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        train => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trainer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        training => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trait => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traitor => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        trajectory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tram => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tramp => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tramway => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tranquil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tranquility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        transact => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transaction => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        transatlantic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transcendence => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        transcendent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transcendental => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        transcribe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transcriber => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transcript => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        transcription => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transfer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transference => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transferred => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transfixed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transformation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transfusion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transgression => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transient => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transitional => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transitive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transitory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        translate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        translation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        translocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        translucent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transmission => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transmit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transmutation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transparency => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transparent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transplant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transplantation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transport => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transportation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transpose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transposition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        transverse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trapping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trappings => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traps => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trash => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        trashy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traumatic => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        travail => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        travel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traveler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        traveling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        traverse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        travesty => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        trawl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trawler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tray => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treacherous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treachery => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        tread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treadmill => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treason => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        treasure => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        treasurer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        treasury => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treat => { anger => 1, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        treatise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treatment => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treaty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        treble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tree => { anger => 1, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        trek => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trellis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tremble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trembling => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tremendous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tremendously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tremor => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        trench => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trend => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        trending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trendy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        trepidation => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        trespass => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triangle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triangular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tribe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tribulation => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tribunal => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tribune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        tributary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tribute => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        trick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        trickery => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        trickle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tricky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tricycle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trident => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trifle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        trigger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trigonometry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trillion => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trimmer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trimming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trinity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trio => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        tripartite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triple => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triplet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triplicate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tripod => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tripping => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        trite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tritium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        triumph => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        triumphant => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        troll => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trolley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trombone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        troop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trooper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        troops => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trophy => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        tropical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        troublesome => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trough => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        troupe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trousers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trowel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        truce => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        truck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        true => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        truism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trump => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        trumpet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trumpeter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        truncate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        truncated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trundle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        trunk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        truss => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        trust => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        trustee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        trusty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        truth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        truthful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        truthfulness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        tryout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tub => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tube => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tubular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tubule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tuck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tucker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tufted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tug => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tuition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tulip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tumble => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tumbler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tumor => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tumour => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tumult => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        tumultuous => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tun => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tuna => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tunable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tune => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tunic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tuning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tunnel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turban => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turbidity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turbine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turbulence => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turbulent => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turmeric => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turmoil => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        turn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turnkey => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turnpike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turntable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turquoise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turret => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        turtleneck => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tussle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tutelage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        tutor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        tweak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twelfth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twelve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twentieth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twenty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twilight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        twine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twinkle => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        twins => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twisted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twitch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        twofold => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tycoon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        type => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        typewriter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        typhoon => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        typically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        typist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        typography => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tyrannical => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        tyranny => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tyrant => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        tyre => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ubiquitous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ubiquity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ugliness => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ugly => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ulcer => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ulterior => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ultimate => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ultimately => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        ultimatum => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ultimo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ultraviolet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        umbilical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        umbra => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        umbrella => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        umpire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unabashed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unabated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unacceptable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unaccompanied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unaccountable => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        unacknowledged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unadulterated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unaided => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unaltered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unambiguous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unanimity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unanimous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unanimously => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unanticipated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unapproved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unarmed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unassisted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unassuming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unattached => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unattainable => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unattended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unattractive => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unauthorized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unavoidable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unaware => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbalanced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbearable => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unbeaten => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 0 },
        unbelief => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbelievable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbiased => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unborn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbound => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbounded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unbreakable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unbridled => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        unbroken => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        uncanny => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        uncaring => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        uncertain => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        uncertainty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unchallenged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unchangeable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unchanged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unclaimed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unclean => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncomfortable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncommon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncommonly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncompromising => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconcerned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconfirmed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconnected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconscionable => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconscious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconsciousness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconstitutional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconstrained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        uncontested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncontrollable => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        uncontrolled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconventional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unconvinced => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncooked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncorrelated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        uncritical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uncut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undecided => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undefined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undeniable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undercover => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undercurrent => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underestimate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        undergo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undergraduate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underground => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underlie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underline => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        undermined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underneath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underpaid => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        underpants => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underscore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undersized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        understanding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        understood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undertake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undertaker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        undertaking => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underwood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        underwrite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        underwriter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undeserved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undesirable => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        undesired => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        undeveloped => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undirected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undisclosed => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undiscovered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        undisputed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undisturbed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undivided => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        undo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undoing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undoubted => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undress => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undressed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        undying => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 0, trust => 1 },
        unearned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unearth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uneasiness => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        uneasy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uneducated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unemployed => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unencumbered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unending => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unequal => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unequalled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unequivocal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        unequivocally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        uneven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uneventful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unexpected => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        unexpectedly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unexplained => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unexplored => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unfailing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unfair => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unfairness => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unfaithful => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unfamiliar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unfavorable => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unfettered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unfinished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unflinching => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unfold => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unforeseen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unforgiving => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unfortunate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unfriendly => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unfulfilled => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        unfurnished => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ungodly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        ungrateful => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unguarded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unhappiness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unhappy => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unharmed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unhealthy => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unhindered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unholy => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unicorn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unification => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        uniform => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uniformity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uniformly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unimaginable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        unimportant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unimpressed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unimproved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uninfected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        uninformed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uninhabited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uninitiated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uninspired => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unintelligible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unintended => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unintentional => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unintentionally => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        uninterested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        uninteresting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        uninterrupted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uninvited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        union => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unique => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        unison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unitary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unite => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        united => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        universal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        universality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        universe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        university => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unjust => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unjustifiable => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unjustified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unkind => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unknowable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unknown => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unlawful => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unleash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unlicensed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unlike => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unlimited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unload => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unloaded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unlock => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unlucky => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unmanageable => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmarked => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmarried => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmask => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmatched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmistakable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmitigated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unmoved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unnamed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unnatural => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unnecessary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unneeded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unnoticed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unnumbered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unobserved => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unobstructed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unobtrusive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unoccupied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unofficial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unopened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unopposed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unordered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unorganized => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unorthodox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unpack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unpaid => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unpleasant => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unpopular => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unprecedented => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unpredictable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unprepared => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unpretentious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unproductive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unprofitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unprotected => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unproven => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unpublished => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unquestionable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unquestionably => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unquestioned => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unreal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrealistic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrecorded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unregistered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unregulated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrelated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrelenting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unreliable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        unrepentant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrequited => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unresolved => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrest => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unrestrained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unrestricted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unruly => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsafe => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsatisfactory => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsatisfied => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unsavory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unscathed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unscientific => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unscrupulous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unseat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unseen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unselfish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        unsettled => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsightly => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsophisticated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unspeakable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unspecified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unstable => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unsteady => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsuccessful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unsuitable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsung => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsupported => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsurpassed => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unsuspecting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        unsustainable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsweetened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unsympathetic => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untamed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untenable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unthinkable => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untidy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        untimely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untitled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        untold => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untouched => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untoward => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untrained => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untranslated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untrue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        untrustworthy => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unused => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unusual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unusually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unveil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unveiling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unverified => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwarranted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwashed => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwavering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        unwelcome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unwell => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        unwilling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwillingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwillingness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwitting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwittingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unworthy => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unwritten => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        unyielding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upheaval => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        uphill => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        upholstery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upland => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uplands => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uplift => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        upper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        uprising => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uproar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upset => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        upshot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upstairs => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upstart => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        upwards => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        uranium => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        urban => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        urchin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        urge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        urgency => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        urgent => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        urinalysis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        urn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        usage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        usefully => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        usefulness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        useless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        usher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        usual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        usurp => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        usurped => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        usury => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utensil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utilitarian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        utilization => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utilize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utmost => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utopian => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        utterance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        utterly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vacancy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vacation => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vaccination => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vaccine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vacuolar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vacuole => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vacuous => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vacuum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vague => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vagueness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vainly => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        valance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        valet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        valiant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        validity => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        valley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        valor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        valuable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        valuation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        valve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vamp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vampire => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        van => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vanguard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vanilla => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vanish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        vanished => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        vanity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vanquish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vapor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vara => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        variable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        variance => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        variation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        variations => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        varicella => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        varicose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        varied => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        variegated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        variety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vascular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vase => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vaudeville => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vault => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vaulted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vaulting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 1 },
        vector => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veer => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        vega => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vegetable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vegetarian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vegetarianism => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vegetation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vegetative => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        vehement => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vehicle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veil => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veiled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vein => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veined => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vellum => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        velocity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        velour => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        velvet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        velvety => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vena => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vendetta => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        vendor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veneer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venerable => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        veneration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vengeance => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vengeful => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venison => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venom => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venomous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vent => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ventilation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ventilator => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ventricle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ventricular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venture => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        venue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veracity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        veranda => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verbal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verbatim => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verbiage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verbose => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verbosity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verdant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        verdict => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verge => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verification => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        verified => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        verify => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        veritable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vermin => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vernacular => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vernal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        veronica => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        versatile => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        versatility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        version => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        versus => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vert => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vertebra => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vertebral => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vertex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vertical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vertically => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vertigo => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        verve => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vesicle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vesicular => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vessel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vested => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vestibule => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vestige => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veteran => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        veterinarian => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        veto => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viability => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viaduct => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vial => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vibrate => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vibration => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vibratory => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vicar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        vicarious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vicinity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vicious => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        victim => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        victimized => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        victor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        victoria => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        victorious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        victory => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        videotape => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vie => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        view => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vigil => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vigilance => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        vigilant => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        vignette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vigor => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vigorous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        viking => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        villa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        village => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        villager => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        villain => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        villainous => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vinaigrette => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vindicate => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vindicated => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vindication => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        vindictive => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vinegar => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vineyard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viola => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        violation => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        violence => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        violent => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        violently => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        violet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        violin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        violinist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viper => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        virgin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        virginity => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        virology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        virtual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        virtually => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        virtue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        virtuoso => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        virtuous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        virulence => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        virus => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visa => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visage => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viscosity => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        viscous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visibility => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visible => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visibly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vision => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        visionary => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        visit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        visitation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visiting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visitor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        visor => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        vista => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visual => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        visualize => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vital => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vitality => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        vitreous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vivacious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vivid => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vixen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vocabulary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vocal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vocalist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vocation => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vogue => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voice => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voiceless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        void => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        volatility => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        volcanic => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        volcano => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        volition => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        volley => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voltmeter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        volume => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voluminous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voluntarily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voluntary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        volunteer => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        volunteering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        volunteers => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        voluptuous => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        vomit => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vomiting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voodoo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voracious => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vortex => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vote => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        voting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        votive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        vouch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        voucher => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        vow => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        vowel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voyage => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        voyager => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vulgar => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vulgarity => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        vulnerability => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        vulnerable => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        vulture => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wad => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wade => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wafer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waffle => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wag => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wager => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wages => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wagon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wail => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        waist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waistcoat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wait => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waiter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waiting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waive => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wake => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        walk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        walker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wallet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wallow => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        walnut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waltz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wan => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wand => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wander => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wanderer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wandering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wane => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        waning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wanting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        war => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warbler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warden => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        wardrobe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ware => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warehouse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warfare => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        warlike => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warlock => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warming => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warn => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 1 },
        warned => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        warning => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warp => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        warped => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warrant => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warranted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warrants => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warranty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        warren => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        warrior => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wart => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wary => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wash => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        washing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        washout => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wasp => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waste => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wasted => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wasteful => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wasting => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        watch => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        watchdog => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        watchful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        watchman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        water => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        watercourse => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        watered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waterproof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        waterworks => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        watery => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waver => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wavering => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waves => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wavy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wax => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        waxy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        ways => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wayward => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weakened => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weakly => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        weakness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wealth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        wealthy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weapon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        wearily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        weariness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wearing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weary => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        weather => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weathered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weatherproof => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        weave => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        web => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wedded => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wedge => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wee => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weeding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weeds => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        weedy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        week => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weekly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weep => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        weeping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        weigh => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        weighing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weight => { anger => 0, anticipation => 1, disgust => 1, fear => 1, joy => 1, negative => 1, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        weightless => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weights => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weighty => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weir => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weird => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        weirdo => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        welcomed => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        weld => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        welfare => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wellhead => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        welt => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wench => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        western => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whack => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whale => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wham => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wharf => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whatsoever => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wheel => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wheels => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whereabouts => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wherefore => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wherewith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wherewithal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whet => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whiff => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whilst => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whim => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        whimper => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        whimsical => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whimsy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whine => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        whip => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whirl => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whirlpool => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whirlwind => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whisk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whisker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whisky => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whisper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whispered => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whistle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        white => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        whiteness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        whitish => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whiz => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wholesome => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        wholly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whoop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whopping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        whore => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wick => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wicked => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wickedness => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wicker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wicket => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        widely => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        widen => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        widespread => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        widow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        widower => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        width => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wield => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wife => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wig => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wight => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wild => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        wildcat => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wilderness => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wildfire => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        willful => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        willingly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        willingness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        willow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wilted => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wily => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wimp => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wimpy => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wince => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        winch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wind => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        windfall => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        winding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        windmill => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        window => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        windy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wine => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        winged => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wink => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        winner => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        winning => { anger => 0, anticipation => 1, disgust => 1, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 1, surprise => 1, trust => 1 },
        winnings => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        winter => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wintry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wipe => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wire => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wireless => { anger => 1, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        wis => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wisdom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        wise => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wishful => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wistful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wit => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        witch => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        witchcraft => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        withal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        withdraw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        withdrawal => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wither => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        withered => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        withstand => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        witness => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 1 },
        wits => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        witty => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wizard => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        woe => { anger => 0, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        woeful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        woefully => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        woman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        womanhood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        womanly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        womb => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wonderful => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        wonderfully => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        wondrous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        wont => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        woo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wood => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        woodcut => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wooden => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        woodlands => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        woody => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wooing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wool => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        woolly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wop => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        word => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        wording => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        words => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wordy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        work => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        workbook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        worker => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        working => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        workman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        workmanship => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        workplace => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        works => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        workshop => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        world => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        worldly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        worldwide => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        worm => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        worn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worried => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worry => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worrying => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worse => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worsening => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worship => { anger => 0, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        worth => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        worthless => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        worthy => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        wot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        wound => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrangler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrangling => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrapper => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrapping => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrath => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wreak => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wreath => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wreck => { anger => 1, anticipation => 0, disgust => 1, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 1, trust => 0 },
        wrecked => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrench => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrest => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrestle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrestler => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrestling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wretch => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wretched => { anger => 0, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wright => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wring => { anger => 1, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrinkle => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrinkled => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrist => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wristband => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wristwatch => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        writ => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        write => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        writer => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        writing => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        written => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrong => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wrongdoing => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrongful => { anger => 1, anticipation => 0, disgust => 1, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrongly => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 1, surprise => 0, trust => 0 },
        wrought => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        wry => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        xenophobia => { anger => 0, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        xerox => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yacht => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yachting => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yak => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yam => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yank => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yard => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yarn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yaw => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yawn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yawning => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yea => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        year => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yearbook => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yearling => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yearly => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yearn => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yearning => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 1, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        years => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yeast => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yell => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        yellow => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yellows => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yelp => { anger => 1, anticipation => 0, disgust => 0, fear => 1, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        yeoman => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yesterday => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yesteryear => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yew => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yield => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yielding => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yogi => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yoke => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yolk => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yon => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        yonder => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        young => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        younger => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 0 },
        youth => { anger => 1, anticipation => 1, disgust => 0, fear => 1, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 0 },
        zany => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 1, trust => 0 },
        zap => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zeal => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 1, trust => 1 },
        zealot => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zealous => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        zebra => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zenith => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zephyr => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zeppelin => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zest => { anger => 0, anticipation => 1, disgust => 0, fear => 0, joy => 1, negative => 0, positive => 1, sadness => 0, surprise => 0, trust => 1 },
        zip => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 1, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zodiac => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zone => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zoo => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zoological => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zoology => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
        zoom => { anger => 0, anticipation => 0, disgust => 0, fear => 0, joy => 0, negative => 0, positive => 0, sadness => 0, surprise => 0, trust => 0 },
    );
    return \%wordlist;
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Lingua::EN::Opinion::Emotion

=head1 VERSION

version 0.0503

=head1 DESCRIPTION

NRC Word-Emotion Association Lexicon
(NRC Emotion Lexicon)
Version 0.92
10 July 2011
Copyright (C) 2011 National Research Council Canada (NRC)
Contact: Saif Mohammad (saif.mohammad@nrc-cnrc.gc.ca)

1. This copy of the NRC Emotion Lexicon is to be used for research
purposes only.  Please contact NRC if interested in a commercial
license.

2. If you use this lexicon in your research, then please cite
at least one of the papers listed in the PUBLICATIONS section of the
README (preferably the journal paper in Computational Intelligence).

.......................................................................

NRC EMOTION LEXICON
-------------------
The NRC emotion lexicon is a list of words and their associations with
eight emotions (anger, fear, anticipation, trust, surprise, sadness,
joy, and disgust) and two sentiments (negative and positive). The
annotations were manually done through Amazon's Mechanical Turk. Refer
to publications below for more details.

.......................................................................

=head1 ATTRIBUTES

=head2 wordlist

HashRef entries of the form:

  word => { anger=>0, anticipation=>0, disgust=>0, fear=>0, joy=>0, negative=>0, positive=>0, sadness=>0, surprise=>0, trust=>0 },

=head1 AUTHOR

Gene Boggs <gene@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Gene Boggs.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
